@@ -19,14 +19,14 @@
  * that were not received from the exchange, by auditor.
  * @author Nic Eigel
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-auditor-httpd.h"
 #include "taler-auditor-httpd_deposit-confirmation-get.h"
 
