@@ -18,13 +18,13 @@
  * @brief audits an exchange's aggregations.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
-#include "taler_auditordb_plugin.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_bank_service.h"
-#include "taler_signatures.h"
-#include "taler_dbevents.h"
+#include "taler/taler_auditordb_plugin.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_dbevents.h"
 #include "report-lib.h"
 
 /**
