@@ -18,14 +18,11 @@
  * @brief audits the reserves of an exchange database
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include <gnunet/gnunet_util_lib.h>
-#include "taler_auditordb_plugin.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_bank_service.h"
-#include "taler_signatures.h"
+#include "taler/platform.h"
+#include "taler/taler_auditordb_plugin.h"
 #include "report-lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_exchangedb_lib.h"
 
 
 /**
@@ -234,7 +231,7 @@ report_row_inconsistency (const char *table,
 
 
 /* ***************************** Analyze reserves ************************ */
-/* This logic checks the reserves_in, reserves_out and reserves-tables */
+/* This logic checks the reserves_in, withdraw and reserves-tables */
 
 /**
  * Summary data we keep per reserve.
@@ -512,11 +509,11 @@ handle_reserve_in (
  *
  * @param cls our `struct ReserveContext`
  * @param rowid unique serial ID for the refresh session in our DB
- * @param num_evs number of elements in @e h_blind_evs
- * @param h_blind_evs array @e num_evs of blinded hashes of the coin's public keys
- * @param denom_serials array @e num_evs of serial ID's of denominations in our DB
+ * @param num_denom_serials number of elements in @e denom_serials array
+ * @param denom_serials array with length @e num_denom_serials of serial ID's of denominations in our DB
+ * @param selected_h hash over the gamma-selected planchets
  * @param h_planchets running hash over all hashes of blinded planchets in the original withdraw request
- * @param blinding_seed the master seed used for CS denominations; might be NULL
+ * @param blinding_seed the blinding seed for CS denominations that was provided during withdraw; might be NULL
  * @param age_proof_required true if the withdraw request required an age proof.
  * @param max_age if @e age_proof_required is true, the maximum age that was set on the coins.
  * @param noreveal_index if @e age_proof_required is true, the index that was returned by the exchange for the reveal phase.
@@ -530,9 +527,9 @@ static enum GNUNET_GenericReturnValue
 handle_withdrawals (
   void *cls,
   uint64_t rowid,
-  size_t num_evs,
-  const struct TALER_BlindedCoinHashP *h_blind_evs,
+  size_t num_denom_serials,
   const uint64_t *denom_serials,
+  const struct TALER_HashBlindedPlanchetsP *selected_h,
   const struct TALER_HashBlindedPlanchetsP *h_planchets,
   const struct TALER_BlindingMasterSeedP *blinding_seed,
   bool age_proof_required,
@@ -552,6 +549,9 @@ handle_withdrawals (
   enum GNUNET_DB_QueryStatus qs;
 
   /* should be monotonically increasing */
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Analyzing withdrawal row %llu\n",
+              (unsigned long long) rowid);
   GNUNET_assert (rowid >= TALER_ARL_USE_PP (reserves_withdraw_serial_id));
   TALER_ARL_USE_PP (reserves_withdraw_serial_id) = rowid + 1;
 
@@ -562,7 +562,7 @@ handle_withdrawals (
   GNUNET_assert (GNUNET_OK == TALER_amount_set_zero (TALER_ARL_currency,
                                                      &auditor_amount_with_fee));
 
-  for (size_t i = 0; i < num_evs; i++)
+  for (size_t i = 0; i < num_denom_serials; i++)
   {
     /* lookup denomination pub data (make sure denom_pub is valid, establish fees);
        initializes wsrd.h_denomination_pub! */
@@ -573,14 +573,17 @@ handle_withdrawals (
       GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
       if (GNUNET_DB_STATUS_HARD_ERROR == qs)
         GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Hard database error trying to get denomination by serial %lu (%s) from database!\n",
-                    denom_serials[i],
+                    "Hard database error trying to get denomination by serial %llu (%s) from database!\n",
+                    (unsigned long long) denom_serials[i],
                     GNUNET_h2s (&h_planchets->hash));
       rc->qs = qs;
       return GNUNET_SYSERR;
     }
     if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
     {
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "Denomination #%llu not found\n",
+                  (unsigned long long) denom_serials[i]);
       report_row_inconsistency ("withdraw",
                                 rowid,
                                 "denomination key not found");
@@ -588,6 +591,10 @@ handle_withdrawals (
         return GNUNET_SYSERR;
       return GNUNET_OK;
     }
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Analyzing withdrawn denomination #%llu (%s)\n",
+                (unsigned long long) denom_serials[i],
+                TALER_amount2s (&issue->value));
 
     /* check that execution date is within withdraw range for denom_pub  */
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
@@ -611,6 +618,9 @@ handle_withdrawals (
         .reserve_pub = *reserve_pub
       };
 
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "Withdraw outside of denomination #%llu validity period detected\n",
+                  (unsigned long long) denom_serials[i]);
       qs =
         TALER_ARL_adb->insert_denomination_key_validity_withdraw_inconsistency (
           TALER_ARL_adb->cls,
@@ -623,6 +633,9 @@ handle_withdrawals (
         return GNUNET_SYSERR;
       }
     }
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Adding withdraw fee of denomination (%s)\n",
+                TALER_amount2s (&issue->fees.withdraw));
     TALER_ARL_amount_add (&auditor_amount,
                           &auditor_amount,
                           &issue->value);
@@ -649,11 +662,11 @@ handle_withdrawals (
         h_planchets,
         blinding_seed,
         age_proof_required
-          ? &issue->age_mask
-          : NULL,
+        ? &issue->age_mask
+        : NULL,
         age_proof_required
-          ? max_age
-          : 0,
+        ? max_age
+        : 0,
         reserve_pub,
         reserve_sig))
   {
@@ -664,10 +677,12 @@ handle_withdrawals (
       .operation_specific_pub = reserve_pub->eddsa_pub
     };
 
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Withdraw signature invalid (row #%llu)\n",
+                (unsigned long long) rowid);
     qs = TALER_ARL_adb->insert_bad_sig_losses (
       TALER_ARL_adb->cls,
       &bsl);
-
     if (qs < 0)
     {
       GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
@@ -684,6 +699,9 @@ handle_withdrawals (
       TALER_amount_cmp (&auditor_amount_with_fee,
                         amount_with_fee))
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "Withdraw fee inconsistent (row #%llu)\n",
+                (unsigned long long) rowid);
     report_row_inconsistency ("withdraw",
                               rowid,
                               "amount with fee from exchange does not match denomination value plus fee");
