@@ -16,8 +16,8 @@
 #ifndef PG_DELETE_WIRE_OUT_INCONSISTENCY_IF_MATCHING_H
 #define PG_DELETE_WIRE_OUT_INCONSISTENCY_IF_MATCHING_H
 
-#include "taler_util.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 /**
