@@ -18,9 +18,9 @@
 #define SRC_PG_GET_AUDITOR_CLOSURE_LAGS_H
 
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_auditordb_plugin.h"
 
 /**
  * Get information about auditor closure lags from the database.
