@@ -17,8 +17,8 @@
 #ifndef SRC_PG_GET_DENOMINATION_KEY_VALIDITY_WITHDRAW_INCONSISTENCY_H
 #define SRC_PG_GET_DENOMINATION_KEY_VALIDITY_WITHDRAW_INCONSISTENCY_H
 
-#include "taler_util.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_auditordb_plugin.h"
 
 /**
  * Get information about denominations key validity withdraw inconsistency from the database.
