@@ -16,9 +16,9 @@
 #ifndef PG_GET_RESERVES_H
 #define PG_GET_RESERVES_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_auditordb_plugin.h"
 
 /**
  * Get information about reserves from the database.
