@@ -22,12 +22,14 @@
 #define PG_HELPER_H
 
 
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 // FIXME: comment
 const char *
-TAH_PG_get_deletable_suppressable_table_name (enum TALER_AUDITORDB_DeletableSuppressableTables table);
+TAH_PG_get_deletable_suppressable_table_name (enum
+                                              TALER_AUDITORDB_DeletableSuppressableTables
+                                              table);
 
 
 /**
