@@ -16,9 +16,9 @@
 #ifndef SRC_PG_INSERT_AMOUNT_ARITHMETIC_INCONSISTENCY_H
 #define SRC_PG_INSERT_AMOUNT_ARITHMETIC_INCONSISTENCY_H
 
-#include "taler_util.h"
-// #include "taler_json_lib.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+// #include "taler/taler_json_lib.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 /**
