@@ -17,8 +17,8 @@
 #ifndef SRC_PG_INSERT_FEE_TIME_INCONSISTENCY_H
 #define SRC_PG_INSERT_FEE_TIME_INCONSISTENCY_H
 
-#include "taler_util.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_auditordb_plugin.h"
 
 
 /**
