@@ -13,8 +13,8 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-#include "platform.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_helper.h"
 #include "pg_insert_misattribution_in_inconsistency.h"
 
