@@ -13,8 +13,8 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-#include "platform.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_helper.h"
 #include "pg_insert_reserve_not_closed_inconsistency.h"
 
@@ -41,7 +41,8 @@ TAH_PG_insert_reserve_not_closed_inconsistency (
            " balance,"
            " expiration_time,"
            " diagnostic"
-           ") VALUES ($1,$2,$3,$4);"
+           ") VALUES ($1,$2,$3,$4)"
+           " ON CONFLICT DO NOTHING;"
            );
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "auditor_reserve_not_closed_inconsistency_insert",
