@@ -14,8 +14,8 @@
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
 
-#include "platform.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_helper.h"
 #include "pg_insert_row_inconsistency.h"
 
