@@ -21,9 +21,9 @@
 #ifndef PG_SELECT_HISTORIC_RESERVE_REVENUE_H
 #define PG_SELECT_HISTORIC_RESERVE_REVENUE_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_auditordb_plugin.h"
 
 /**
  * Return information about an exchange's historic revenue from reserves.
