@@ -67,6 +67,7 @@
 #include "pg_get_coin_inconsistency.h"
 #include "pg_get_row_inconsistency.h"
 #include "pg_update_balance.h"
+#include "pg_select_early_aggregations.h"
 
 #include "pg_insert_coin_inconsistency.h"
 #include "pg_insert_row_inconsistency.h"
@@ -706,6 +707,8 @@ libtaler_plugin_auditordb_postgres_init (void *cls)
     = &TAH_PG_select_reserve_in_inconsistency;
   plugin->delete_reserve_in_inconsistency
     = &TAH_PG_delete_reserve_in_inconsistency;
+  plugin->select_early_aggregations
+    = &TAH_PG_select_early_aggregations;
 
   plugin->insert_reserve_balance_summary_wrong_inconsistency =
     &TAH_PG_insert_reserve_balance_summary_wrong_inconsistency;
