@@ -19,9 +19,9 @@
  * @author Gabor X Toth
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_db_lib.h>
-#include "taler_auditordb_plugin.h"
+#include "taler/taler_auditordb_plugin.h"
 
 /**
  * Currency we use, must match CURRENCY in "test-auditor-db-postgres.conf".
