@@ -19,7 +19,7 @@
  * @brief Common functions for the bank API
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include "bank_api_common.h"
 
 
