@@ -24,9 +24,9 @@
 #ifndef FAKEBANK_COMMON_MAKE_ADMIN_TRANSFER_H
 #define FAKEBANK_COMMON_MAKE_ADMIN_TRANSFER_H
 
-#include "taler_fakebank_lib.h"
-#include "taler_bank_service.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_mhd_lib.h"
 #include <gnunet/gnunet_mhd_compat.h>
 #include "fakebank.h"
 
