@@ -21,11 +21,12 @@
  * @brief library that fakes being a Taler bank for testcases
  * @author Christian Grothoff <christian@grothoff.org>
  */
-#include "platform.h"
-#include "taler_fakebank_lib.h"
-#include "taler_bank_service.h"
-#include "taler_mhd_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_mhd_lib.h"
 #include <gnunet/gnunet_mhd_compat.h>
+#include <gnunet/gnunet_mhd_lib.h>
 #include "fakebank.h"
 #include "fakebank_common_make_admin_transfer.h"
 #include "fakebank_twg_admin_add_incoming.h"
@@ -40,7 +41,7 @@ TALER_FAKEBANK_twg_admin_add_incoming_ (
   void **con_cls)
 {
   struct ConnectionContext *cc = *con_cls;
-  enum GNUNET_JSON_PostResult pr;
+  enum GNUNET_MHD_PostResult pr;
   json_t *json;
   uint64_t row_id;
   struct GNUNET_TIME_Timestamp timestamp;
@@ -48,29 +49,29 @@ TALER_FAKEBANK_twg_admin_add_incoming_ (
   if (NULL == cc)
   {
     cc = GNUNET_new (struct ConnectionContext);
-    cc->ctx_cleaner = &GNUNET_JSON_post_parser_cleanup;
+    cc->ctx_cleaner = &GNUNET_MHD_post_parser_cleanup;
     *con_cls = cc;
   }
-  pr = GNUNET_JSON_post_parser (REQUEST_BUFFER_MAX,
-                                connection,
-                                &cc->ctx,
-                                upload_data,
-                                upload_data_size,
-                                &json);
+  pr = GNUNET_MHD_post_parser (REQUEST_BUFFER_MAX,
+                               connection,
+                               &cc->ctx,
+                               upload_data,
+                               upload_data_size,
+                               &json);
   switch (pr)
   {
-  case GNUNET_JSON_PR_OUT_OF_MEMORY:
+  case GNUNET_MHD_PR_OUT_OF_MEMORY:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_CONTINUE:
+  case GNUNET_MHD_PR_CONTINUE:
     return MHD_YES;
-  case GNUNET_JSON_PR_REQUEST_TOO_LARGE:
+  case GNUNET_MHD_PR_REQUEST_TOO_LARGE:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_JSON_INVALID:
+  case GNUNET_MHD_PR_JSON_INVALID:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_SUCCESS:
+  case GNUNET_MHD_PR_SUCCESS:
     break;
   }
   {
