@@ -32,6 +32,7 @@
 #include "taler/taler_templating_lib.h"
 #include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_withdraw.h"
+#include "taler-exchange-httpd_aml-accounts-get.h"
 #include "taler-exchange-httpd_aml-attributes-get.h"
 #include "taler-exchange-httpd_aml-decision.h"
 #include "taler-exchange-httpd_aml-legitimization-measures-get.h"
@@ -590,6 +591,10 @@ handle_get_aml (struct TEH_RequestContext *rc,
     AmlOpGetHandler handler;
 
   } h[] = {
+    {
+      .op = "accounts",
+      .handler = &TEH_handler_aml_accounts_get
+    },
     {
       .op = "attributes",
       .handler = &TEH_handler_aml_attributes_get
