@@ -24,10 +24,10 @@
 #define TALER_EXCHANGE_HTTPD_H
 
 #include <microhttpd.h>
-#include "taler_json_lib.h"
-#include "taler_util.h"
-#include "taler_kyclogic_plugin.h"
-#include "taler_extensions.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_kyclogic_plugin.h"
+#include "taler/taler_extensions.h"
 #include <gnunet/gnunet_mhd_compat.h>
 
 
@@ -74,6 +74,11 @@ extern int TEH_allow_keys_timetravel;
  */
 extern int TEH_enable_kyc;
 
+/**
+ * Option set to #GNUNET_YES to disable direct deposits.
+ */
+extern int TEH_disable_direct_deposit;
+
 /**
  * Main directory with revocation data.
  */
@@ -148,6 +153,12 @@ extern struct TALER_Amount TEH_tiny_amount;
  */
 extern char *TEH_shopping_url;
 
+/**
+ * URL where wallets can find an open banking gateway API to
+ * initiate wire transfers to withdraw money from this exchange. Can be NULL.
+ */
+extern char *TEH_obg_url;
+
 /**
  * Linear STEFAN parameter.
  */
