@@ -18,16 +18,16 @@
  * @brief Return summary information about KYC attributes
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
-#include "taler_signatures.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_signatures.h"
 #include "taler-exchange-httpd.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_plugin.h"
 #include "taler-exchange-httpd_aml-attributes-get.h"
 #include "taler-exchange-httpd_metrics.h"
 
@@ -66,7 +66,7 @@ detail_cb (
   }
   GNUNET_assert (
     0 ==
-    json_array_append (
+    json_array_append_new (
       records,
       GNUNET_JSON_PACK (
         GNUNET_JSON_pack_int64 ("rowid",
