@@ -22,19 +22,19 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_extensions_policy.h"
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_extensions_policy.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_common_kyc.h"
 #include "taler-exchange-httpd_batch-deposit.h"
 #include "taler-exchange-httpd_responses.h"
-#include "taler_exchangedb_lib.h"
+#include "taler/taler_exchangedb_lib.h"
 #include "taler-exchange-httpd_keys.h"
 
 
@@ -1110,9 +1110,12 @@ bdc_cleaner (struct TEH_RequestContext *rc)
     TEH_legitimization_check_cancel (bdc->lch);
     bdc->lch = NULL;
   }
-  for (unsigned int i = 0; i<bdc->bd.num_cdis; i++)
-    TALER_denom_sig_free (&bdc->cdis[i].coin.denom_sig);
-  GNUNET_free (bdc->cdis);
+  if (0 != bdc->cdis)
+  {
+    for (unsigned int i = 0; i<bdc->bd.num_cdis; i++)
+      TALER_denom_sig_free (&bdc->cdis[i].coin.denom_sig);
+    GNUNET_free (bdc->cdis);
+  }
   GNUNET_free (bdc->deposit_fees);
   json_decref (bdc->policy_json);
   GNUNET_free (bdc);
