@@ -18,14 +18,14 @@
  * @brief shared logic for finishing a KYC process
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include "taler-exchange-httpd.h"
 #include "taler-exchange-httpd_common_kyc.h"
-#include "taler_attributes.h"
-#include "taler_error_codes.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_exchangedb_lib.h"
+#include "taler/taler_attributes.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_lib.h"
 #include <gnunet/gnunet_common.h>
 
 /**
@@ -1584,6 +1584,9 @@ legitimization_check_run (
     qs = TEH_plugin->get_kyc_rules (
       TEH_plugin->cls,
       &lch->h_payto,
+      lch->have_merchant_pub
+      ? &lch->merchant_pub
+      : NULL,
       &no_account_pub,
       &lch->lcr.kyc.account_pub,
       &no_reserve_pub,
