@@ -22,7 +22,7 @@
 #define TALER_EXCHANGE_HTTPD_DB_H
 
 #include <microhttpd.h>
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_plugin.h"
 #include "taler-exchange-httpd_metrics.h"
 #include <gnunet/gnunet_mhd_compat.h>
 
