@@ -441,7 +441,7 @@ TEH_resume_keys_requests (bool do_shutdown);
  */
 enum TALER_ErrorCode
 TEH_keys_exchange_sign_ (
-  const struct GNUNET_CRYPTO_EccSignaturePurpose *purpose,
+  const struct GNUNET_CRYPTO_SignaturePurpose *purpose,
   struct TALER_ExchangePublicKeyP *pub,
   struct TALER_ExchangeSignatureP *sig);
 
@@ -463,7 +463,7 @@ TEH_keys_exchange_sign_ (
 enum TALER_ErrorCode
 TEH_keys_exchange_sign2_ (
   void *cls,
-  const struct GNUNET_CRYPTO_EccSignaturePurpose *purpose,
+  const struct GNUNET_CRYPTO_SignaturePurpose *purpose,
   struct TALER_ExchangePublicKeyP *pub,
   struct TALER_ExchangeSignatureP *sig);
 
