@@ -18,17 +18,17 @@
  * @brief Handle request for generic KYC check.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_mhd_lib.h"
-#include "taler_signatures.h"
-#include "taler_dbevents.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_kyc-check.h"
 #include "taler-exchange-httpd_kyc-wallet.h"
@@ -76,6 +76,18 @@ struct KycPoller
    */
   union TALER_AccountSignatureP account_sig;
 
+  /**
+   * Public key from the account owner authorizing this
+   * operation. Optional, see @e have_pub.
+   */
+  union TALER_AccountPublicKeyP account_pub;
+
+  /**
+   * Generation of KYC rules already known to the client
+   * (when long-polling). Do not send these rules again.
+   */
+  uint64_t min_rule;
+
   /**
    * What are we long-polling for (if anything)?
    */
@@ -86,6 +98,11 @@ struct KycPoller
    */
   bool suspended;
 
+  /**
+   * True if we have an @e account_pub.
+   */
+  bool have_pub;
+
 };
 
 
@@ -191,12 +208,13 @@ TEH_handler_kyc_check (
   struct KycPoller *kyp = rc->rh_ctx;
   json_t *jrules = NULL;
   json_t *jlimits = NULL;
-  union TALER_AccountPublicKeyP account_pub;
   union TALER_AccountPublicKeyP reserve_pub;
   struct TALER_AccountAccessTokenP access_token;
   bool aml_review;
   bool kyc_required;
   bool access_ok = false;
+  bool is_wallet;
+  uint64_t rule_gen = 0;
 
   if (NULL == kyp)
   {
@@ -228,6 +246,11 @@ TEH_handler_kyc_check (
       TALER_HTTP_HEADER_ACCOUNT_OWNER_SIGNATURE,
       &kyp->account_sig,
       sig_required);
+    TALER_MHD_parse_request_header_auto (
+      rc->connection,
+      TALER_HTTP_HEADER_ACCOUNT_OWNER_PUBKEY,
+      &kyp->account_pub,
+      kyp->have_pub);
     TALER_MHD_parse_request_timeout (rc->connection,
                                      &kyp->timeout);
     {
@@ -255,6 +278,9 @@ TEH_handler_kyc_check (
                       kyp->timeout),
                     true));
     }
+    TALER_MHD_parse_request_number (rc->connection,
+                                    "min_rule",
+                                    &kyp->min_rule);
     /* long polling needed? */
     if (GNUNET_TIME_absolute_is_future (kyp->timeout))
     {
@@ -292,14 +318,18 @@ TEH_handler_kyc_check (
     bool do_suspend;
 
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Looking up KYC requirements for account %s\n",
-                TALER_B2S (&kyp->h_payto));
+                "Looking up KYC requirements for account %s (%s)\n",
+                TALER_B2S (&kyp->h_payto),
+                kyp->have_pub ? "with account-pub" : "legacy wallet");
     qs = TEH_plugin->lookup_kyc_requirement_by_row (
       TEH_plugin->cls,
       &kyp->h_payto,
-      &account_pub,
+      kyp->have_pub,
+      &kyp->account_pub,
+      &is_wallet,
       &reserve_pub.reserve_pub,
       &access_token,
+      &rule_gen,
       &jrules,
       &aml_review,
       &kyc_required);
@@ -311,6 +341,10 @@ TEH_handler_kyc_check (
         TALER_EC_GENERIC_DB_STORE_FAILED,
         "lookup_kyc_requirement_by_row");
     }
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Found rule %llu (client wants > %llu)\n",
+                (unsigned long long) rule_gen,
+                (unsigned long long) kyp->min_rule);
     do_suspend = false;
     if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
     {
@@ -328,15 +362,16 @@ TEH_handler_kyc_check (
     else
     {
       access_ok =
-        ( (! GNUNET_is_zero (&account_pub) &&
+        ( (! GNUNET_is_zero (&kyp->account_pub) &&
            (GNUNET_OK ==
-            TALER_account_kyc_auth_verify (&account_pub,
+            TALER_account_kyc_auth_verify (&kyp->account_pub,
                                            &kyp->account_sig)) ) ||
           (! GNUNET_is_zero (&reserve_pub) &&
            (GNUNET_OK ==
             TALER_account_kyc_auth_verify (&reserve_pub,
                                            &kyp->account_sig)) ) );
-      if (GNUNET_TIME_absolute_is_future (kyp->timeout))
+      if (GNUNET_TIME_absolute_is_future (kyp->timeout) &&
+          (rule_gen <= kyp->min_rule) )
       {
         switch (kyp->lpt)
         {
@@ -392,7 +427,7 @@ TEH_handler_kyc_check (
   {
     json_decref (jrules);
     jrules = NULL;
-    if (GNUNET_is_zero (&account_pub))
+    if (GNUNET_is_zero (&kyp->account_pub))
     {
       GNUNET_break_op (0);
       return TALER_MHD_reply_with_error (
@@ -409,10 +444,19 @@ TEH_handler_kyc_check (
       TALER_JSON_pack_ec (
         TALER_EC_EXCHANGE_KYC_CHECK_AUTHORIZATION_FAILED),
       GNUNET_JSON_pack_data_auto ("expected_account_pub",
-                                  &account_pub));
+                                  &kyp->account_pub));
   }
 
-  jlimits = TALER_KYCLOGIC_rules_to_limits (jrules);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "KYC rules apply to %s:\n",
+              is_wallet ? "wallet" : "account");
+  if (NULL != jrules)
+    json_dumpf (jrules,
+                stderr,
+                JSON_INDENT (2));
+
+  jlimits = TALER_KYCLOGIC_rules_to_limits (jrules,
+                                            is_wallet);
   if (NULL == jlimits)
   {
     GNUNET_break_op (0);
@@ -427,6 +471,12 @@ TEH_handler_kyc_check (
   json_decref (jrules);
   jrules = NULL;
 
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "KYC limits apply:\n");
+  json_dumpf (jlimits,
+              stderr,
+              JSON_INDENT (2));
+
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Returning KYC %s\n",
               kyc_required ? "required" : "optional");
@@ -437,6 +487,8 @@ TEH_handler_kyc_check (
     : MHD_HTTP_OK,
     GNUNET_JSON_pack_bool ("aml_review",
                            aml_review),
+    GNUNET_JSON_pack_uint64 ("rule_gen",
+                             rule_gen),
     GNUNET_JSON_pack_data_auto ("access_token",
                                 &access_token),
     GNUNET_JSON_pack_allow_null (
