@@ -18,18 +18,18 @@
  * @brief Handle request for generic KYC info.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_mhd_lib.h"
-#include "taler_signatures.h"
-#include "taler_dbevents.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_kyc-info.h"
 #include "taler-exchange-httpd_responses.h"
@@ -365,13 +365,10 @@ resume_with_reply (struct KycPoller *kyp,
   json_array_foreach ((json_t *) measures, i, mi)
   {
     const char *check_name;
-    const char *prog_name;
     const json_t *context = NULL;
     struct GNUNET_JSON_Specification ispec[] = {
       GNUNET_JSON_spec_string ("check_name",
                                &check_name),
-      GNUNET_JSON_spec_string ("prog_name",
-                               &prog_name),
       GNUNET_JSON_spec_mark_optional (
         GNUNET_JSON_spec_object_const ("context",
                                        &context),
@@ -395,9 +392,8 @@ resume_with_reply (struct KycPoller *kyp,
       return;
     }
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Found required check `%s' with program `%s'\n",
-                check_name,
-                prog_name);
+                "Found required check `%s'\n",
+                check_name);
     if (NULL != context)
     {
       json_dumpf (context,
@@ -443,7 +439,6 @@ resume_with_reply (struct KycPoller *kyp,
     }
     kri = TALER_KYCLOGIC_measure_to_requirement (
       check_name,
-      prog_name,
       context,
       &kyp->access_token,
       i,
@@ -576,8 +571,8 @@ current_rules_cb (
                               GNUNET_JSON_pack_allow_null (
                                 GNUNET_JSON_pack_array_steal (
                                   "voluntary_measures",
-                                  TALER_KYCLOGIC_voluntary_measures
-                                    (kyp->lrs))
+                                  TALER_KYCLOGIC_voluntary_measures (
+                                    kyp->lrs))
                                 )));
       return;
     }
@@ -661,7 +656,8 @@ current_rules_cb (
                                             NULL,
                                             MHD_RESPMEM_PERSISTENT);
     add_nocache_header (resp);
-    TALER_MHD_add_global_headers (resp);
+    TALER_MHD_add_global_headers (resp,
+                                  false);
     GNUNET_break (MHD_YES ==
                   MHD_add_response_header (resp,
                                            MHD_HTTP_HEADER_ETAG,
