@@ -25,7 +25,7 @@
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
-#include "taler_mhd_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_responses.h"
 
 
