@@ -18,16 +18,16 @@
  * @brief Handle notification of KYC completion via webhook.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_attributes.h"
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
-#include "taler_kyclogic_lib.h"
+#include "taler/taler_attributes.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_kyclogic_lib.h"
 #include "taler-exchange-httpd_common_kyc.h"
 #include "taler-exchange-httpd_kyc-webhook.h"
 #include "taler-exchange-httpd_responses.h"
@@ -206,6 +206,7 @@ kyc_aml_webhook_finished (
  * @param cls closure
  * @param process_row legitimization process the webhook was about
  * @param account_id account the webhook was about
+ * @param is_wallet true if @a account_id is for a wallet
  * @param provider_name name of the KYC provider that was run
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
@@ -220,6 +221,7 @@ webhook_finished_cb (
   void *cls,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -258,6 +260,7 @@ webhook_finished_cb (
       &kwh->rc->async_scope_id,
       process_row,
       account_id,
+      is_wallet,
       &kyc_aml_webhook_finished,
       kwh);
     if (NULL == kwh->kat)
