@@ -20,19 +20,19 @@
  *        to the database.
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include <pthread.h>
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_db.h"
 #include "taler-exchange-httpd_recoup-refresh.h"
 #include "taler-exchange-httpd_responses.h"
 #include "taler-exchange-httpd_keys.h"
-#include "taler_exchangedb_lib.h"
+#include "taler/taler_exchangedb_lib.h"
 
 
 /**
