@@ -20,12 +20,12 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
-#include "taler_mhd_lib.h"
-#include "taler_json_lib.h"
-#include "taler_dbevents.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_dbevents.h"
 #include "taler-exchange-httpd_keys.h"
 #include "taler-exchange-httpd_reserves_get.h"
 #include "taler-exchange-httpd_responses.h"
