@@ -18,15 +18,15 @@
  * @brief Handle /reveal-withdraw requests
  * @author Özgür Kesim
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_common.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <microhttpd.h>
 #include "taler-exchange-httpd_metrics.h"
-#include "taler_error_codes.h"
-#include "taler_exchangedb_plugin.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_mhd_lib.h"
 #include "taler-exchange-httpd_mhd.h"
 #include "taler-exchange-httpd_reveal-withdraw.h"
 #include "taler-exchange-httpd_responses.h"
@@ -215,7 +215,7 @@ calculate_blinded_hash (
   MHD_RESULT *result)
 {
   enum GNUNET_GenericReturnValue ret;
-  struct TALER_AgeCommitmentHash ach;
+  struct TALER_AgeCommitmentHashP ach;
 
   /* calculate age commitment hash */
   {
