@@ -66,7 +66,7 @@ enum WithdrawError
   WITHDRAW_ERROR_KYC_REQUIRED,
   WITHDRAW_ERROR_LEGITIMIZATION_RESULT,
   WITHDRAW_ERROR_MAXIMUM_AGE_TOO_LARGE,
-  WITHDRAW_ERROR_NONCE_RESUSE,
+  WITHDRAW_ERROR_NONCE_REUSE,
   WITHDRAW_ERROR_REQUEST_PARAMETER_MALFORMED,
   WITHDRAW_ERROR_RESERVE_CIPHER_UNKNOWN,
   WITHDRAW_ERROR_RESERVE_SIGNATURE_INVALID,
@@ -507,7 +507,7 @@ withdraw_transaction (
   {
     GNUNET_break (0);
     SET_ERROR (wc,
-               WITHDRAW_ERROR_NONCE_RESUSE);
+               WITHDRAW_ERROR_NONCE_REUSE);
     return GNUNET_DB_STATUS_HARD_ERROR;
   }
 
@@ -1500,6 +1500,14 @@ phase_generate_reply_error (
                    TALER_EC_EXCHANGE_WITHDRAW_IDEMPOTENT_PLANCHET,
                    NULL));
     return;
+  case WITHDRAW_ERROR_NONCE_REUSE:
+    finish_loop (wc,
+                 TALER_MHD_reply_with_error (
+                   wc->rc->connection,
+                   MHD_HTTP_CONFLICT,
+                   TALER_EC_EXCHANGE_WITHDRAW_NONCE_REUSE,
+                   NULL));
+    return;
   case WITHDRAW_ERROR_RESERVE_SIGNATURE_INVALID:
     finish_loop (wc,
                  TALER_MHD_reply_with_ec (
