@@ -21,14 +21,14 @@ CREATE FUNCTION exchange_do_insert_aml_decision(
   IN in_h_full_payto BYTEA, -- can be NULL!
   IN in_decision_time INT8,
   IN in_expiration_time INT8,
-  IN in_properties TEXT, -- can be NULL
+  IN in_properties JSONB, -- can be NULL
   IN in_kyc_attributes_enc BYTEA, -- can be NULL
   IN in_kyc_attributes_hash BYTEA, -- can be NULL
   IN in_kyc_attributes_expiration INT8, -- can be NULL
-  IN in_new_rules TEXT,
+  IN in_new_rules JSONB,
   IN in_to_investigate BOOLEAN,
   IN in_new_measure_name TEXT, -- can be NULL
-  IN in_jmeasures TEXT, -- can be NULL
+  IN in_jmeasures JSONB, -- can be NULL
   IN in_justification TEXT, -- can be NULL
   IN in_decider_pub BYTEA, -- can be NULL
   IN in_decider_sig BYTEA, -- can be NULL
@@ -300,6 +300,19 @@ LOOP
     ) VALUES (
      in_decision_time
     ,ini_event);
+  IF (ini_event = 'ACCOUNT_OPEN')
+  THEN
+    UPDATE kyc_targets
+       SET open_time=in_decision_time
+          ,close_time=NULL
+     WHERE h_normalized_payto=in_h_normalized_payto;
+  END IF;
+  IF (ini_event = 'ACCOUNT_IDLE')
+  THEN
+    UPDATE kyc_targets
+       SET close_time=in_decision_time
+     WHERE h_normalized_payto=in_h_normalized_payto;
+  END IF;
 END LOOP;
 
 -- wake up taler-exchange-aggregator
@@ -320,5 +333,5 @@ EXECUTE FORMAT (
 END $$;
 
 
-COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, BYTEA, BYTEA, INT8, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT, TEXT[], TEXT)
+COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, JSONB, BYTEA, BYTEA, INT8, JSONB, BOOLEAN, TEXT, JSONB, TEXT, BYTEA, BYTEA, TEXT, TEXT[], TEXT)
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
