@@ -20,7 +20,7 @@ CREATE FUNCTION exchange_do_insert_successor_measure(
   IN in_decision_time INT8,
   IN in_expiration_time INT8,
   IN in_new_measure_name TEXT, -- can be NULL
-  IN in_jmeasures TEXT, -- can be NULL
+  IN in_jmeasures JSONB, -- can be NULL
   OUT out_last_date INT8,
   OUT out_account_unknown BOOLEAN,
   OUT out_legitimization_measure_serial_id INT8
@@ -153,7 +153,7 @@ INSERT INTO legitimization_outcomes
   (in_h_normalized_payto
   ,in_decision_time
   ,in_expiration_time
-  ,'{}'
+  ,'{}'::JSONB
   ,in_new_measure_name
   ,FALSE
   ,NULL
@@ -166,5 +166,5 @@ INSERT INTO legitimization_outcomes
 END $$;
 
 
-COMMENT ON FUNCTION exchange_do_insert_successor_measure(BYTEA, INT8, INT8, TEXT, TEXT)
+COMMENT ON FUNCTION exchange_do_insert_successor_measure(BYTEA, INT8, INT8, TEXT, JSONB)
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
