@@ -28,6 +28,8 @@ CREATE PROCEDURE exchange_do_kycauth_in_insert(
   IN in_notify_s TEXT)
 LANGUAGE plpgsql
 AS $$
+DECLARE
+  my_is_wallet BOOL;
 BEGIN
 
   INSERT INTO kycauths_in
@@ -53,22 +55,34 @@ BEGIN
     RETURN;
   END IF;
 
-  UPDATE wire_targets
+  UPDATE kyc_targets
      SET target_pub=in_account_pub
-   WHERE wire_target_h_payto=in_wire_source_h_payto;
+   WHERE h_normalized_payto=in_h_normalized_payto;
 
   IF NOT FOUND
   THEN
+    -- First time we see this account, setup everything.
+    my_is_wallet
+      = (LOWER (SUBSTRING (in_payto_uri, 22)) =
+         'payto://taler-reserve/') OR
+        (LOWER (SUBSTRING (in_payto_uri, 27)) =
+         'payto://taler-reserve-http/');
+    INSERT INTO kyc_targets
+      (h_normalized_payto
+      ,is_wallet
+      ,target_pub
+      ) VALUES (
+       in_h_normalized_payto
+      ,my_is_wallet
+      ,in_account_pub);
     INSERT INTO wire_targets
       (wire_target_h_payto
       ,h_normalized_payto
       ,payto_uri
-      ,target_pub
       ) VALUES (
        in_wire_source_h_payto
       ,in_h_normalized_payto
-      ,in_payto_uri
-      ,in_account_pub);
+      ,in_payto_uri);
   END IF;
 
   EXECUTE FORMAT (
