@@ -14,10 +14,13 @@
 -- TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 --
 
+-- When parameter names have changed, we can not REPLACE
+-- but need to drop first
+DROP FUNCTION IF EXISTS exchange_do_recoup_to_reserve;
 
-CREATE OR REPLACE FUNCTION exchange_do_recoup_to_reserve(
+CREATE FUNCTION exchange_do_recoup_to_reserve(
   IN in_reserve_pub BYTEA,
-  IN in_reserve_out_serial_id INT8,
+  IN in_withdraw_id INT8,
   IN in_coin_blind BYTEA,
   IN in_coin_pub BYTEA,
   IN in_known_coin_id INT8,
@@ -130,7 +133,7 @@ INSERT INTO exchange.recoup
   ,coin_blind
   ,amount
   ,recoup_timestamp
-  ,reserve_out_serial_id
+  ,withdraw_id
   )
 VALUES
   (in_coin_pub
@@ -138,7 +141,7 @@ VALUES
   ,in_coin_blind
   ,tmp
   ,in_recoup_timestamp
-  ,in_reserve_out_serial_id);
+  ,in_withdraw_id);
 
 -- Normal end, everything is fine.
 out_recoup_ok=TRUE;
