@@ -18,10 +18,10 @@
  * @brief helper function to build AML inputs from account histories
  * @author Christian Grothoff
  */
-#include "taler_exchangedb_plugin.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_common.h>
 
 /**
