@@ -18,10 +18,10 @@
  * @brief benchmark for select_refunds_by_coin
  * @author Joseph Xu
  */
-#include "platform.h"
-#include "taler_exchangedb_lib.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/platform.h"
+#include "taler/taler_exchangedb_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 #include "math.h"
 
 /**
@@ -389,7 +389,7 @@ run (void *cls)
 
     {
       struct TALER_DenominationHashP dph;
-      struct TALER_AgeCommitmentHash agh;
+      struct TALER_AgeCommitmentHashP agh;
 
       FAILIF (TALER_EXCHANGEDB_CKS_ADDED !=
               plugin->ensure_coin_known (plugin->cls,
