@@ -101,7 +101,7 @@ TEH_PG_add_policy_fulfillment_proof (
              ",fulfillment_proof"
              ",h_fulfillment_proof"
              ",policy_hash_codes"
-             ") VALUES ($1, $2, $3, $4)"
+             ") VALUES ($1, $2::TEXT::JSON, $3, $4)"
              " ON CONFLICT DO NOTHING;");
     qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                    "insert_proof_into_policy_fulfillments",
