@@ -21,9 +21,9 @@
 #ifndef PG_COMPLETE_SHARD_H
 #define PG_COMPLETE_SHARD_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Function called to persist that work on a shard was completed.
