@@ -21,9 +21,9 @@
 #ifndef PG_DELETE_SHARD_LOCKS_H
 #define PG_DELETE_SHARD_LOCKS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Function called to delete all revolving shards.
  * To be used after a crash or when the shard size is
