@@ -18,10 +18,10 @@
  * @brief Implementation of the do_deposit function for Postgres
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_do_deposit.h"
 #include "pg_helper.h"
 #include "pg_compute_shard.h"
@@ -77,6 +77,8 @@ TEH_PG_do_deposit (
                                        pg->conn),
     TALER_PQ_query_param_amount (pg->conn,
                                  &total_amount),
+    GNUNET_PQ_query_param_bool (TALER_payto_is_wallet (
+                                  bd->receiver_wire_account.full_payto)),
     GNUNET_PQ_query_param_end
   };
   bool no_time;
@@ -129,8 +131,7 @@ TEH_PG_do_deposit (
            ",out_insufficient_balance_coin_index AS insufficient_balance_coin_index"
            ",out_conflict AS conflicted"
            " FROM exchange_do_deposit"
-           " ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19);")
-  ;
+           " ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19,$20);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "call_deposit",
                                                  params,
