@@ -21,9 +21,9 @@
 #ifndef PG_EVENT_LISTEN_CANCEL_H
 #define PG_EVENT_LISTEN_CANCEL_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 
 /**
@@ -35,4 +35,5 @@
 void
 TEH_PG_event_listen_cancel (void *cls,
                             struct GNUNET_DB_EventHandler *eh);
+
 #endif
