@@ -21,9 +21,9 @@
 #ifndef PG_EVENT_NOTIFY_H
 #define PG_EVENT_NOTIFY_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Notify all that listen on @a es of an event.
