@@ -21,9 +21,9 @@
 #ifndef PG_INJECT_AUDITOR_TRIGGERS_H
 #define PG_INJECT_AUDITOR_TRIGGERS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Function called to inject auditor triggers into the
