@@ -167,7 +167,8 @@ TEH_PG_insert_aml_decision (
            ",out_legitimization_measure_serial_id"
            ",out_is_wallet"
            " FROM exchange_do_insert_aml_decision"
-           "($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19);");
+           "($1,$2,$3,$4,$5,$6::TEXT::JSONB,$7,$8,$9,$10::TEXT::JSONB"
+           ",$11,$12,$13::TEXT::JSONB,$14,$15,$16,$17,$18,$19);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "do_insert_aml_decision",
                                                  params,
