@@ -77,7 +77,7 @@ TEH_PG_insert_successor_measure (
            ",out_last_date"
            ",out_legitimization_measure_serial_id"
            " FROM exchange_do_insert_successor_measure"
-           "($1, $2, $3, $4, $5);");
+           "($1, $2, $3, $4, $5::TEXT::JSONB);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "do_insert_successor_measure",
                                                  params,
