@@ -21,9 +21,9 @@
 #ifndef PG_ITERATE_ACTIVE_AUDITORS_H
 #define PG_ITERATE_ACTIVE_AUDITORS_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Function called to invoke @a cb on every active auditor. Disabled
