@@ -21,9 +21,9 @@
 #ifndef PG_LOOKUP_AUDITOR_TIMESTAMP_H
 #define PG_LOOKUP_AUDITOR_TIMESTAMP_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Check the last date an auditor was modified.
@@ -38,4 +38,5 @@ TEH_PG_lookup_auditor_timestamp (
   void *cls,
   const struct TALER_AuditorPublicKeyP *auditor_pub,
   struct GNUNET_TIME_Timestamp *last_date);
+
 #endif
