@@ -109,7 +109,7 @@ TEH_PG_lookup_kyc_requirement_by_row (
            " out_account_pub AS account_pub"
            ",out_reserve_pub AS reserve_pub"
            ",out_access_token AS access_token"
-           ",out_jrules AS jrules"
+           ",out_jrules::TEXT AS jrules"
            ",out_is_wallet AS is_wallet"
            ",out_not_found AS not_found"
            ",out_aml_review AS aml_review"
