@@ -52,7 +52,7 @@ TEH_PG_lookup_kyc_status_by_token (
            "lookup_kyc_status_by_token",
            "SELECT"
            " legitimization_measure_serial_id"
-           ",jmeasures"
+           ",jmeasures::TEXT"
            " FROM legitimization_measures"
            " WHERE access_token=$1"
            "   AND NOT is_finished"
