@@ -21,9 +21,9 @@
 #ifndef PG_LOOKUP_SIGNKEY_REVOCATION_H
 #define PG_LOOKUP_SIGNKEY_REVOCATION_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Obtain information about a revoked online signing key.
