@@ -21,9 +21,9 @@
 #ifndef PG_PREFLIGTH_H
 #define PG_PREFLIGTH_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 
 /**
@@ -36,8 +36,6 @@
  *         #GNUNET_NO if a transaction was rolled back
  *         #GNUNET_SYSERR on hard errors
  */
-
-
 enum GNUNET_GenericReturnValue
 TEH_PG_preflight (void *cls);
 
