@@ -18,10 +18,10 @@
  * @brief Implementation of the profit_drains_set_finished function for Postgres
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_profit_drains_set_finished.h"
 #include "pg_helper.h"
 
