@@ -21,9 +21,9 @@
 #ifndef PG_RELEASE_REVOLVING_SHARD_H
 #define PG_RELEASE_REVOLVING_SHARD_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 /**
  * Function called to release a revolving shard
  * back into the work pool.  Clears the
