@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022, 2024 Taler Systems SA
+   Copyright (C) 2022, 2024, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -18,10 +18,10 @@
  * @brief Implementation of the reserves_get_origin function for Postgres
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_error_codes.h"
-#include "taler_dbevents.h"
-#include "taler_pq_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_dbevents.h"
+#include "taler/taler_pq_lib.h"
 #include "pg_reserves_get_origin.h"
 #include "pg_helper.h"
 
@@ -51,12 +51,12 @@ TEH_PG_reserves_get_origin (
   PREPARE (pg,
            "get_h_wire_source_of_reserve",
            "SELECT"
-           " wire_source_h_payto"
-           ",payto_uri"
+           " rt.wire_source_h_payto"
+           ",wt.payto_uri"
            " FROM reserves_in rt"
            " JOIN wire_targets wt"
            "   ON (rt.wire_source_h_payto = wt.wire_target_h_payto)"
-           " WHERE reserve_pub=$1");
+           " WHERE rt.reserve_pub=$1");
   return GNUNET_PQ_eval_prepared_singleton_select (
     pg->conn,
     "get_h_wire_source_of_reserve",
