@@ -146,7 +146,7 @@ TEH_PG_select_all_kyc_attributes (
            " lp.provider_name"
            ",ka.h_payto"
            ",ka.kyc_attributes_serial_id"
-           ",lo.jproperties"
+           ",lo.jproperties::TEXT"
            ",ka.collection_time"
            ",ka.expiration_time"
            ",ka.encrypted_attributes"
