@@ -21,9 +21,9 @@
 #ifndef PG_SELECT_MERGE_AMOUNTS_FOR_KYC_CHECK_H
 #define PG_SELECT_MERGE_AMOUNTS_FOR_KYC_CHECK_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Call @a kac on merged reserve amounts after @a time_limit which are relevant for a
