@@ -21,9 +21,9 @@
 #ifndef PG_SELECT_PURSE_MERGE_H
 #define PG_SELECT_PURSE_MERGE_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Function called to approve merging of a purse with
