@@ -21,9 +21,9 @@
 #ifndef PG_SELECT_REFUNDS_BY_COIN_H
 #define PG_SELECT_REFUNDS_BY_COIN_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Select refunds by @a coin_pub, @a merchant_pub and @a h_contract.
