@@ -21,9 +21,9 @@
 #ifndef PG_UPDATE_KYC_PROCESS_BY_ROW_H
 #define PG_UPDATE_KYC_PROCESS_BY_ROW_H
 
-#include "taler_util.h"
-#include "taler_json_lib.h"
-#include "taler_exchangedb_plugin.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_plugin.h"
 
 /**
  * Update KYC requirement check with provider-linkage and/or
