@@ -189,6 +189,7 @@
 #include "pg_select_exchange_credit_transfers.h"
 #include "pg_select_exchange_debit_transfers.h"
 #include "pg_select_exchange_kycauth_transfers.h"
+#include "pg_select_kyc_accounts.h"
 #include "pg_select_kyc_attributes.h"
 #include "pg_select_merge_amounts_for_kyc_check.h"
 #include "pg_select_purse.h"
@@ -708,6 +709,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_insert_auditor_denom_sig;
   plugin->select_auditor_denom_sig
     = &TEH_PG_select_auditor_denom_sig;
+  plugin->select_kyc_accounts
+    = &TEH_PG_select_kyc_accounts;
   plugin->add_denomination_key
     = &TEH_PG_add_denomination_key;
   plugin->lookup_signing_key
