@@ -806,18 +806,22 @@ typedef enum GNUNET_GenericReturnValue
  * and have not yet seen a wire transfer.
  *
  * @param cls closure
- * @param batch_deposit_serial_id where in the table are we
+ * @param row_id row ID of the alert in the auditor database
+ * @param batch_deposit_serial_id where in the exchange table are we
  * @param total_amount value of all missing deposits, including fees
  * @param wire_target_h_payto hash of the recipient account's payto URI
  * @param deadline what was the earliest requested wire transfer deadline
+ * @param suppressed true if this report was suppressed
  */
 typedef void
 (*TALER_AUDITORDB_WireMissingCallback) (
   void *cls,
+  uint64_t row_id,
   uint64_t batch_deposit_serial_id,
   const struct TALER_Amount *total_amount,
   const struct TALER_FullPaytoHashP *wire_target_h_payto,
-  struct GNUNET_TIME_Timestamp deadline);
+  struct GNUNET_TIME_Timestamp deadline,
+  bool suppressed);
 
 
 /**
@@ -915,6 +919,50 @@ typedef enum GNUNET_GenericReturnValue
   const struct TALER_AUDITORDB_RowMinorInconsistencies *dc);
 
 
+/**
+ * Information about an early aggregation event.
+ */
+struct TALER_AUDITORDB_EarlyAggregation
+{
+  /**
+   * Row of the event in the auditor database.
+   */
+  uint64_t row_id;
+
+  /**
+   * Row of the batch deposit in the exchange database.
+   */
+  uint64_t batch_deposit_serial_id;
+
+  /**
+   * FIXME
+   */
+  uint64_t tracking_serial_id;
+
+  /**
+   * Total amount involved.
+   */
+  struct TALER_Amount total;
+
+  /**
+   * True if this report was previously suppressed.
+   */
+  bool suppressed;
+};
+
+
+/**
+ * Function to call with information about early aggregations.
+ *
+ * @param cls closure
+ * @param ea event data
+ * @return #GNUNET_OK to continue to iterate
+ */
+typedef enum GNUNET_GenericReturnValue
+(*TALER_AUDITORDB_EarlyAggregationsCallback)(
+  void *cls,
+  const struct TALER_AUDITORDB_EarlyAggregation *ea);
+
 /**
  * @brief The plugin API, returned from the plugin's "init" function.
  * The argument given to "init" is simply a configuration handle.
@@ -1562,6 +1610,27 @@ struct TALER_AUDITORDB_Plugin
     TALER_AUDITORDB_ReserveNotClosedInconsistencyCallback cb,
     void *cb_cls);
 
+  /**
+   * Returns all aggregations that were found that were done
+   * too early.
+   *
+   * @param cls closure
+   * @param limit number of rows to return, negative to iterate backwards
+   * @param offset starting offset, exclusive
+   * @param return_suppressed true to also return suppressed events
+   * @param cb function to call with results
+   * @param cb_cls closure for @a cb
+   * @return transaction status
+   */
+  enum GNUNET_DB_QueryStatus
+  (*select_early_aggregations)(
+    void *cls,
+    int64_t limit,
+    uint64_t offset,
+    bool return_suppressed,
+    TALER_AUDITORDB_EarlyAggregationsCallback cb,
+    void *cb_cls);
+
 
   enum GNUNET_DB_QueryStatus
   (*delete_reserve_not_closed_inconsistency)(
@@ -1920,6 +1989,9 @@ struct TALER_AUDITORDB_Plugin
    * seen the required wire transfer.
    *
    * @param deadline only return up to this deadline
+   * @param limit number of rows to return, negative to iterate backwards
+   * @param offset starting offset, exclusive
+   * @param return_suppressed true to also return suppressed events
    * @param cb function to call on each entry
    * @param cb_cls closure for @a cb
    * @return transaction status code
@@ -1928,6 +2000,9 @@ struct TALER_AUDITORDB_Plugin
   (*select_pending_deposits)(
     void *cls,
     struct GNUNET_TIME_Absolute deadline,
+    int64_t limit,
+    uint64_t offset,
+    bool return_suppressed,
     TALER_AUDITORDB_WireMissingCallback cb,
     void *cb_cls);
 
@@ -2132,6 +2207,8 @@ struct TALER_AUDITORDB_Plugin
    * Return information about an exchange's historic revenue from reserves.
    *
    * @param cls the @e cls of this struct with the plugin-specific state
+   * @param limit number of rows to return, negative to iterate backwards
+   * @param offset starting offset, exclusive
    * @param cb function to call with results
    * @param cb_cls closure for @a cb
    * @return transaction status code
