@@ -41,9 +41,9 @@
  * @deprecated
  */
 #define TALER_json_warn(error)                                         \
-        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,                                \
-                    "JSON parsing failed at %s:%u: %s (%s)\n",                  \
-                    __FILE__, __LINE__, error.text, error.source)
+  GNUNET_log (GNUNET_ERROR_TYPE_WARNING,                                \
+              "JSON parsing failed at %s:%u: %s (%s)\n",                  \
+              __FILE__, __LINE__, error.text, error.source)
 
 
 /**
@@ -67,8 +67,8 @@ TALER_JSON_pack_time_abs_human (
  * @param ec error code to encode using canonical field names
  */
 #define TALER_JSON_pack_ec(ec) \
-        GNUNET_JSON_pack_string ("hint", TALER_ErrorCode_get_hint (ec)), \
-        GNUNET_JSON_pack_uint64 ("code", ec)
+  GNUNET_JSON_pack_string ("hint", TALER_ErrorCode_get_hint (ec)), \
+  GNUNET_JSON_pack_uint64 ("code", ec)
 
 
 /**
@@ -209,6 +209,21 @@ TALER_JSON_pack_amount (
   const struct TALER_Amount *amount);
 
 
+/**
+ * Generate packer instruction for a JSON field that contains an array of
+ * amounts (as strings). If @a amounts is NULL, emits JSON null.
+ *
+ * @param name field name
+ * @param len number of elements in @a amounts
+ * @param amounts array to encode
+ * @return json pack specification
+ */
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_amount_array (const char *name,
+                              size_t len,
+                              const struct TALER_Amount *amounts);
+
+
 /**
  * Generate packer instruction for a JSON field of type
  * full payto.
@@ -346,6 +361,21 @@ TALER_JSON_spec_amount (const char *name,
                         struct TALER_Amount *r_amount);
 
 
+/**
+ * Result specification for an array of amounts. Elements must be strings in
+ * the usual "CUR:VAL.FRAC" notation. Allocates *@a amounts and sets
+ * @a amounts_len on success. Use GNUNET_JSON_parse_free() to release the array.
+ *
+ * @param field name of the field to parse
+ * @param amounts_len where to store the array length
+ * @param amounts where the allocated array pointer is written
+ */
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_amount_any_array (const char *field,
+                                  size_t *amounts_len,
+                                  struct TALER_Amount **amounts);
+
+
 /**
  * Provide specification to parse given JSON object to
  * a currency specification.
@@ -433,7 +463,7 @@ TALER_JSON_spec_otp_type (const char *name,
  * The value could be provided as an integer or
  * as a descriptive string.
  *
- * @param name name of the OTP method type in the JSON
+ * @param name name of the KYC trigger event type in the JSON
  * @param[out] kte where to store the operation type
  * @return spec for parsing trigger event type
  */
@@ -451,10 +481,10 @@ TALER_JSON_spec_kycte (const char *name,
  * @param[out] dfs a `struct TALER_DenomFeeSet` to initialize
  */
 #define TALER_JSON_SPEC_DENOM_FEES(pfx,currency,dfs) \
-        TALER_JSON_spec_amount (pfx "_withdraw", (currency), &(dfs)->withdraw), \
-        TALER_JSON_spec_amount (pfx "_deposit", (currency), &(dfs)->deposit),   \
-        TALER_JSON_spec_amount (pfx "_refresh", (currency), &(dfs)->refresh),   \
-        TALER_JSON_spec_amount (pfx "_refund", (currency), &(dfs)->refund)
+  TALER_JSON_spec_amount (pfx "_withdraw", (currency), &(dfs)->withdraw), \
+  TALER_JSON_spec_amount (pfx "_deposit", (currency), &(dfs)->deposit),   \
+  TALER_JSON_spec_amount (pfx "_refresh", (currency), &(dfs)->refresh),   \
+  TALER_JSON_spec_amount (pfx "_refund", (currency), &(dfs)->refund)
 
 
 /**
@@ -465,10 +495,10 @@ TALER_JSON_spec_kycte (const char *name,
  * @param dfs a `struct TALER_DenomFeeSet` to pack
  */
 #define TALER_JSON_PACK_DENOM_FEES(pfx, dfs) \
-        TALER_JSON_pack_amount (pfx "_withdraw", &(dfs)->withdraw),   \
-        TALER_JSON_pack_amount (pfx "_deposit", &(dfs)->deposit),     \
-        TALER_JSON_pack_amount (pfx "_refresh", &(dfs)->refresh),     \
-        TALER_JSON_pack_amount (pfx "_refund", &(dfs)->refund)
+  TALER_JSON_pack_amount (pfx "_withdraw", &(dfs)->withdraw),   \
+  TALER_JSON_pack_amount (pfx "_deposit", &(dfs)->deposit),     \
+  TALER_JSON_pack_amount (pfx "_refresh", &(dfs)->refresh),     \
+  TALER_JSON_pack_amount (pfx "_refund", &(dfs)->refund)
 
 
 /**
@@ -478,9 +508,9 @@ TALER_JSON_spec_kycte (const char *name,
  * @param[out] gfs a `struct TALER_GlobalFeeSet` to initialize
  */
 #define TALER_JSON_SPEC_GLOBAL_FEES(currency,gfs) \
-        TALER_JSON_spec_amount ("history_fee", (currency), &(gfs)->history),   \
-        TALER_JSON_spec_amount ("account_fee", (currency), &(gfs)->account),   \
-        TALER_JSON_spec_amount ("purse_fee", (currency), &(gfs)->purse)
+  TALER_JSON_spec_amount ("history_fee", (currency), &(gfs)->history),   \
+  TALER_JSON_spec_amount ("account_fee", (currency), &(gfs)->account),   \
+  TALER_JSON_spec_amount ("purse_fee", (currency), &(gfs)->purse)
 
 /**
  * Macro to pack all of the global fees.
@@ -488,9 +518,9 @@ TALER_JSON_spec_kycte (const char *name,
  * @param gfs a `struct TALER_GlobalFeeSet` to pack
  */
 #define TALER_JSON_PACK_GLOBAL_FEES(gfs) \
-        TALER_JSON_pack_amount ("history_fee", &(gfs)->history),     \
-        TALER_JSON_pack_amount ("account_fee", &(gfs)->account),     \
-        TALER_JSON_pack_amount ("purse_fee", &(gfs)->purse)
+  TALER_JSON_pack_amount ("history_fee", &(gfs)->history),     \
+  TALER_JSON_pack_amount ("account_fee", &(gfs)->account),     \
+  TALER_JSON_pack_amount ("purse_fee", &(gfs)->purse)
 
 
 /**
