@@ -19,10 +19,10 @@
  * @author Sree Harsha Totakura <sreeharsha@totakura.in>
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
-#include "taler_util.h"
-#include "taler_json_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
 #include <unistr.h>
 
 
@@ -896,4 +896,38 @@ TALER_JSON_extensions_manifests_hash (const json_t *manifests,
 }
 
 
+json_t *
+TALER_JSON_currency_specs_to_json (
+  const struct TALER_CurrencySpecification *cspec)
+{
+  json_t *ca;
+
+  ca = json_array ();
+  GNUNET_assert (NULL != ca);
+  for (unsigned int i = 0; i<cspec->num_common_amounts; i++)
+    GNUNET_assert (
+      0 ==
+      json_array_append_new (
+        ca,
+        TALER_JSON_from_amount (&cspec->common_amounts[i])));
+  return GNUNET_JSON_PACK (
+    GNUNET_JSON_pack_string ("name",
+                             cspec->name),
+    /* 'currency' is deprecated as of exchange v18 and merchant v6;
+       remove this line once current-age > 6*/
+    GNUNET_JSON_pack_string ("currency",
+                             cspec->currency),
+    GNUNET_JSON_pack_array_steal ("common_amounts",
+                                  ca),
+    GNUNET_JSON_pack_uint64 ("num_fractional_input_digits",
+                             cspec->num_fractional_input_digits),
+    GNUNET_JSON_pack_uint64 ("num_fractional_normal_digits",
+                             cspec->num_fractional_normal_digits),
+    GNUNET_JSON_pack_uint64 ("num_fractional_trailing_zero_digits",
+                             cspec->num_fractional_trailing_zero_digits),
+    GNUNET_JSON_pack_object_incref ("alt_unit_names",
+                                    cspec->map_alt_unit_names));
+}
+
+
 /* End of json/json.c */
