@@ -148,6 +148,123 @@ TALER_JSON_spec_amount_any (const char *name,
 }
 
 
+/**
+ * Closure for parsing amount arrays.
+ */
+struct AmountArrayCtx
+{
+  /**
+   * Pointer where to store the resulting array length.
+   */
+  size_t *len;
+};
+
+
+/**
+ * Parse a JSON array of arbitrary amounts.
+ */
+static enum GNUNET_GenericReturnValue
+parse_amount_any_array (void *cls,
+                        json_t *root,
+                        struct GNUNET_JSON_Specification *spec)
+{
+  struct AmountArrayCtx *ctx = cls;
+  struct TALER_Amount **out = spec->ptr;
+
+  GNUNET_assert (NULL != ctx);
+  GNUNET_assert (NULL != out);
+  *out = NULL;
+  if (NULL != ctx->len)
+    *ctx->len = 0;
+
+  if (! json_is_array (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+
+  {
+    size_t len = json_array_size (root);
+    json_t *entry;
+    size_t idx;
+
+    if (NULL != ctx->len)
+      *ctx->len = len;
+    if (0 == len)
+    {
+      GNUNET_break_op (0);
+      return GNUNET_SYSERR;
+    }
+    *out = GNUNET_new_array (len,
+                             struct TALER_Amount);
+    json_array_foreach (root, idx, entry) {
+      const char *amount_str;
+
+      if (! json_is_string (entry))
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+      amount_str = json_string_value (entry);
+      if (GNUNET_OK !=
+          TALER_string_to_amount (amount_str,
+                                  &(*out)[idx]))
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+    }
+  }
+  return GNUNET_OK;
+}
+
+
+/**
+ * Cleanup helper for the amount array parser.
+ */
+static void
+clean_amount_any_array (void *cls,
+                        struct GNUNET_JSON_Specification *spec)
+{
+  struct AmountArrayCtx *ctx = cls;
+
+  if (NULL != spec->ptr)
+  {
+    GNUNET_free (*(void **) spec->ptr);
+    *(void **) spec->ptr = NULL;
+  }
+  if ( (NULL != ctx) &&
+       (NULL != ctx->len) )
+    *ctx->len = 0;
+  GNUNET_free (ctx);
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_amount_any_array (const char *field,
+                                  size_t *amounts_len,
+                                  struct TALER_Amount **amounts)
+{
+  struct AmountArrayCtx *ctx;
+
+  GNUNET_assert (NULL != amounts_len);
+  GNUNET_assert (NULL != amounts);
+  ctx = GNUNET_new (struct AmountArrayCtx);
+  ctx->len = amounts_len;
+  {
+    struct GNUNET_JSON_Specification ret = {
+      .parser = &parse_amount_any_array,
+      .cleaner = &clean_amount_any_array,
+      .cls = ctx,
+      .field = field,
+      .ptr = amounts
+    };
+
+    return ret;
+  }
+}
+
+
 /**
  * Parse given JSON object to currency spec.
  *
@@ -1911,7 +2028,7 @@ parse_array_fixed (void *cls,
         GNUNET_break_op (0);
         return GNUNET_SYSERR;
       }
-      ptr+=entry_size;
+      ptr += entry_size;
     }
   }
   return GNUNET_OK;
@@ -2011,7 +2128,7 @@ parse_array_of_data (void *cls,
         GNUNET_break_op (0);
         return GNUNET_SYSERR;
       }
-      ptr+=info->entry_size;
+      ptr += info->entry_size;
     }
   }
   return GNUNET_OK;
