@@ -18,10 +18,10 @@
  * @brief helper functions to generate or check /wire replies
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
-#include "taler_util.h"
-#include "taler_json_lib.h"
+#include "taler/taler_util.h"
+#include "taler/taler_json_lib.h"
 
 
 enum GNUNET_GenericReturnValue
