@@ -18,10 +18,10 @@
  * @brief Tests for conversion logic
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 #include <gnunet/gnunet_json_lib.h>
-#include "taler_json_lib.h"
+#include "taler/taler_json_lib.h"
 
 /**
  * Return value from main().
