@@ -18,16 +18,16 @@
  * @brief persona for an authentication flow logic
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_attributes.h"
-#include "taler_kyclogic_plugin.h"
-#include "taler_mhd_lib.h"
-#include "taler_curl_lib.h"
-#include "taler_json_lib.h"
-#include "taler_kyclogic_lib.h"
-#include "taler_templating_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_attributes.h"
+#include "taler/taler_kyclogic_plugin.h"
+#include "taler/taler_mhd_lib.h"
+#include "taler/taler_curl_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_kyclogic_lib.h"
+#include "taler/taler_templating_lib.h"
 #include <regex.h>
-#include "taler_util.h"
+#include "taler/taler_util.h"
 
 
 /**
@@ -1091,7 +1091,8 @@ proof_post_conversion_cb (void *cls,
                 MHD_add_response_header (resp,
                                          MHD_HTTP_HEADER_LOCATION,
                                          ph->pd->post_kyc_redirect_url));
-  TALER_MHD_add_global_headers (resp);
+  TALER_MHD_add_global_headers (resp,
+                                false);
   ph->cb (ph->cb_cls,
           TALER_KYCLOGIC_STATUS_SUCCESS,
           ph->pd->section,
@@ -1579,7 +1580,8 @@ webhook_generic_reply (struct TALER_KYCLOGIC_WebhookHandle *wh,
     expiration = GNUNET_TIME_UNIT_ZERO_ABS;
   resp = MHD_create_response_from_buffer_static (0,
                                                  "");
-  TALER_MHD_add_global_headers (resp);
+  TALER_MHD_add_global_headers (resp,
+                                true);
   wh->cb (wh->cb_cls,
           wh->process_row,
           &wh->h_payto,
