@@ -37,18 +37,18 @@ DOCS_JSON=""
 for ID in $(jq -r '.documents[]|select(.status=="valid")|.id')
 do
     TYPE=$(jq -r ".documents[]|select(.id==\"$ID\")|.type")
-    EXPIRY=$(jq -r ".documents[]|select(.id==\"$ID\")|.expiry_date")
+#    EXPIRY=$(jq -r ".documents[]|select(.id==\"$ID\")|.expiry_date")
     DOCUMENT_FILE=$(mktemp -t tmp.XXXXXXXXXX)
     # Authorization: Token $TOKEN
     DOCUMENT_URL="https://api.kycaid.com/documents/$ID"
     if [ -z "${TOKEN:-}" ]
     then
         wget -q --output-document=- "$DOCUMENT_URL" \
-            | gnunet-base32 > ${DOCUMENT_FILE}
+            | gnunet-base32 > "${DOCUMENT_FILE}"
     else
         wget -q --output-document=- "$DOCUMENT_URL" \
              --header "Authorization: Token $TOKEN" \
-            | gnunet-base32 > ${DOCUMENT_FILE}
+            | gnunet-base32 > "${DOCUMENT_FILE}"
     fi
     DOCS_RAW="$DOCS_RAW --rawfile photo$N \"${DOCUMENT_FILE}\""
     if [ "$N" = 0 ]
@@ -57,7 +57,7 @@ do
     else
         DOCS_JSON="{\"type\":\"$TYPE\",\"image\":\$photo$N},$DOCS_JSON"
     fi
-    N=$(expr $N + 1)
+    N=$((N + 1))
 done
 
 
@@ -81,7 +81,7 @@ else
   # Combine into final result for business.
     echo "$J" \
         | jq \
-              $DOCS_RAW \
+              "$DOCS_RAW" \
               "{\"company_name\":.company_name,\"phone\":.phone,\"email\":.email,\"registration_country\":.registration_country,\"documents\":[${DOCS_JSON}]}" \
         | jq \
               'del(..|select(.==null))'
