@@ -23,10 +23,10 @@ fi
 
 FULLNAME=$(echo "$J" | jq -r '[.first,.last]|join(" ")')
 
-echo $J \
+echo "$J" \
     | jq \
           --arg full_name "${FULLNAME}" \
-          '{$full_name,"birthdate":.birthdate,"id":.id}' \
+          '{FORM_ID:"test",FULL_NAME: $full_name,"DATE_OF_BIRTH":.birthdate,"id":.id,}' \
     | jq \
           'del(..|select(.==null))'
 exit 0
