@@ -20,12 +20,12 @@
  * @author Sree Harsha Totakura <sreeharsha@totakura.in>
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <microhttpd.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_json_lib.h"
-#include "taler_auditor_service.h"
-#include "taler_signatures.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_auditor_service.h"
+#include "taler/taler_signatures.h"
 #include "auditor_api_curl_defaults.h"
 
 
@@ -49,8 +49,9 @@
  * @param code what was the curl error code
  */
 #define CURL_STRERROR(type, function, code)      \
-  GNUNET_log (type, "Curl function `%s' has failed at `%s:%d' with error: %s", \
-              function, __FILE__, __LINE__, curl_easy_strerror (code));
+        GNUNET_log (type, \
+                    "Curl function `%s' has failed at `%s:%d' with error: %s", \
+                    function, __FILE__, __LINE__, curl_easy_strerror (code));
 
 
 /**
