@@ -20,18 +20,18 @@
  * @author Sree Harsha Totakura <sreeharsha@totakura.in>
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_json_lib.h"
-#include "taler_auditor_service.h"
-#include "taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_auditor_service.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_common.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 
 
@@ -626,7 +626,7 @@ TALER_EXCHANGE_batch_deposit (
   {
     const struct TALER_EXCHANGE_CoinDepositDetail *cdd = &cdds[i];
     const struct TALER_EXCHANGE_DenomPublicKey *dki;
-    const struct TALER_AgeCommitmentHash *h_age_commitmentp;
+    const struct TALER_AgeCommitmentHashP *h_age_commitmentp;
     struct TALER_Amount amount_without_fee;
 
     dki = TALER_EXCHANGE_get_denomination_key_by_hash (keys,
