@@ -19,14 +19,14 @@
  * @brief Implementation of the /aml/$OFFICER_PUB/decisions request
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_exchange_service.h"
-#include "taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 
 
@@ -141,8 +141,10 @@ parse_limits (struct TALER_EXCHANGE_LookupAmlDecisions *lh,
       struct GNUNET_JSON_Specification ispec[] = {
         GNUNET_JSON_spec_string ("check_name",
                                  &mi->check_name),
-        GNUNET_JSON_spec_string ("prog_name",
-                                 &mi->prog_name),
+        GNUNET_JSON_spec_mark_optional (
+          GNUNET_JSON_spec_string ("prog_name",
+                                   &mi->prog_name),
+          NULL),
         GNUNET_JSON_spec_mark_optional (
           GNUNET_JSON_spec_object_const ("context",
                                          &mi->context),
