@@ -19,17 +19,17 @@
  * @brief Implementation of the /melt request
  * @author Özgür Kesim
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_json_lib.h"
-#include "taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_common.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
 #include "exchange_api_refresh_common.h"
 
@@ -385,7 +385,8 @@ start_melt (struct TALER_EXCHANGE_MeltHandle_v27 *mh)
     {
       json_t *j_coin = GNUNET_JSON_PACK (
         TALER_JSON_pack_blinded_planchet (NULL,
-                                          &mh->md.kappa_blinded_planchets[k][i]));
+                                          &mh->md.kappa_blinded_planchets[k][i])
+        );
       GNUNET_assert (NULL != j_coin);
       GNUNET_assert (0 ==
                      json_array_append_new (j_envs, j_coin));
