@@ -24,7 +24,7 @@
  * and we want to check that the prototypes match.
  */
 #define TALER_TESTING_EXPORTS_DANGEROUS 1
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_common.h>
 #include <jansson.h>
 #include <microhttpd.h> /* just for HTTP status codes */
@@ -32,15 +32,15 @@
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
 #include <sys/wait.h>
-#include "taler_curl_lib.h"
-#include "taler_error_codes.h"
-#include "taler_json_lib.h"
-#include "taler_exchange_service.h"
+#include "taler/taler_curl_lib.h"
+#include "taler/taler_error_codes.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchange_service.h"
 #include "exchange_api_common.h"
 #include "exchange_api_handle.h"
-#include "taler_signatures.h"
+#include "taler/taler_signatures.h"
 #include "exchange_api_curl_defaults.h"
-#include "taler_util.h"
+#include "taler/taler_util.h"
 
 /**
  * A CoinCandidate is populated from a master secret.
