@@ -26,20 +26,21 @@
 enum GNUNET_GenericReturnValue
 TALER_MHD2_is_https (struct MHD_Request *request)
 {
-  const struct MHD_StringNullable *forwarded_proto;
+  struct MHD_StringNullable forwarded_proto;
   union MHD_RequestInfoFixedData ci;
   union MHD_DaemonInfoFixedData di;
 
-  forwarded_proto = MHD_request_get_value (request,
-                                           MHD_VK_HEADER,
-                                           "X-Forwarded-Proto");
-  if ( (NULL != forwarded_proto) &&
-       (NULL != forwarded_proto->cstr) )
+  if ( (MHD_NO !=
+        MHD_request_get_value (request,
+                               MHD_VK_HEADER,
+                               "X-Forwarded-Proto",
+                               &forwarded_proto)) &&
+       (NULL != forwarded_proto.cstr) )
   {
-    if (0 == strcasecmp (forwarded_proto->cstr,
+    if (0 == strcasecmp (forwarded_proto.cstr,
                          "https"))
       return GNUNET_YES;
-    if (0 == strcasecmp (forwarded_proto->cstr,
+    if (0 == strcasecmp (forwarded_proto.cstr,
                          "http"))
       return GNUNET_NO;
     GNUNET_break (0);
@@ -75,28 +76,32 @@ TALER_MHD2_arg_to_yna (struct MHD_Request *request,
                        enum TALER_EXCHANGE_YesNoAll default_val,
                        enum TALER_EXCHANGE_YesNoAll *yna)
 {
-  const struct MHD_StringNullable *nstr;
+  struct MHD_StringNullable nstr;
 
-  nstr = MHD_request_get_value (request,
-                                MHD_VK_GET_ARGUMENT,
-                                arg);
-  if ( (NULL == nstr) ||
-       (NULL == nstr->cstr) )
+  if ( (MHD_NO ==
+        MHD_request_get_value (request,
+                               MHD_VK_URI_QUERY_PARAM,
+                               arg,
+                               &nstr)) ||
+       (NULL == nstr.cstr) )
   {
     *yna = default_val;
     return true;
   }
-  if (0 == strcasecmp (nstr->cstr, "yes"))
+  if (0 == strcasecmp (nstr.cstr,
+                       "yes"))
   {
     *yna = TALER_EXCHANGE_YNA_YES;
     return true;
   }
-  if (0 == strcasecmp (nstr->cstr, "no"))
+  if (0 == strcasecmp (nstr.cstr,
+                       "no"))
   {
     *yna = TALER_EXCHANGE_YNA_NO;
     return true;
   }
-  if (0 == strcasecmp (nstr->cstr, "all"))
+  if (0 == strcasecmp (nstr.cstr,
+                       "all"))
   {
     *yna = TALER_EXCHANGE_YNA_ALL;
     return true;
