@@ -163,29 +163,31 @@ TALER_MHD2_reply_legal (struct MHD_Request *request,
 
   if (NULL != legal)
   {
-    const struct MHD_StringNullable *mimen;
-    const struct MHD_StringNullable *langn;
+    struct MHD_StringNullable mimen;
+    struct MHD_StringNullable langn;
     const char *mime;
     const char *lang;
     double best_mime_q = 0.0;
     double best_lang_q = 0.0;
 
-    mimen = MHD_request_get_value (request,
-                                   MHD_VK_HEADER,
-                                   MHD_HTTP_HEADER_ACCEPT);
-    if ( (NULL == mimen) ||
-         (NULL == mimen->cstr) )
+    if ( (MHD_NO ==
+          MHD_request_get_value (request,
+                                 MHD_VK_HEADER,
+                                 MHD_HTTP_HEADER_ACCEPT,
+                                 &mimen)) ||
+         (NULL == mimen.cstr) )
       mime = "text/plain";
     else
-      mime = mimen->cstr;
-    langn = MHD_request_get_value (request,
-                                   MHD_VK_HEADER,
-                                   MHD_HTTP_HEADER_ACCEPT_LANGUAGE);
-    if ( (NULL == langn) ||
-         (NULL == langn->cstr) )
+      mime = mimen.cstr;
+    if ( (MHD_NO ==
+          MHD_request_get_value (request,
+                                 MHD_VK_HEADER,
+                                 MHD_HTTP_HEADER_ACCEPT_LANGUAGE,
+                                 &langn)) ||
+         (NULL == langn.cstr) )
       lang = "en";
     else
-      lang = langn->cstr;
+      lang = langn.cstr;
     /* Find best match: must match mime type (if possible), and if
        mime type matches, ideally also language */
     for (struct Terms *p = legal->terms_head;
@@ -241,15 +243,16 @@ TALER_MHD2_reply_legal (struct MHD_Request *request,
 
   if (NULL != t)
   {
-    const struct MHD_StringNullable *etag;
+    struct MHD_StringNullable etag;
 
-    etag = MHD_request_get_value (request,
-                                  MHD_VK_HEADER,
-                                  MHD_HTTP_HEADER_IF_NONE_MATCH);
-    if ( (NULL != etag) &&
-         (NULL != etag->cstr) &&
+    if ( (MHD_NO !=
+          MHD_request_get_value (request,
+                                 MHD_VK_HEADER,
+                                 MHD_HTTP_HEADER_IF_NONE_MATCH,
+                                 &etag)) &&
+         (NULL != etag.cstr) &&
          (NULL != t->terms_etag) &&
-         (0 == strcasecmp (etag->cstr,
+         (0 == strcasecmp (etag.cstr,
                            t->terms_etag)) )
     {
       resp = MHD_response_from_empty (MHD_HTTP_STATUS_NOT_MODIFIED);
