@@ -20,12 +20,12 @@
  * @author Benedikt Mueller
  * @author Christian Grothoff
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_mhd_lib.h>
-#include "taler_json_lib.h"
-#include "taler_mhd_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_mhd_lib.h"
 
 
 enum GNUNET_GenericReturnValue
@@ -176,6 +176,47 @@ TALER_MHD_parse_request_header_data (
 }
 
 
+enum GNUNET_GenericReturnValue
+TALER_MHD_parse_request_arg_rel_time (
+  struct MHD_Connection *connection,
+  const char *label,
+  struct GNUNET_TIME_Relative *duration)
+{
+  const char *ts;
+  char dummy;
+  unsigned long long tms;
+
+  ts = MHD_lookup_connection_value (connection,
+                                    MHD_GET_ARGUMENT_KIND,
+                                    label);
+  if (NULL == ts)
+  {
+    *duration = GNUNET_TIME_UNIT_ZERO;
+    return GNUNET_OK;
+  }
+  if (1 !=
+      sscanf (ts,
+              "%llu%c",
+              &tms,
+              &dummy))
+  {
+    MHD_RESULT mret;
+
+    GNUNET_break_op (0);
+    mret = TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       label);
+    return (MHD_YES == mret)
+      ? GNUNET_NO
+      : GNUNET_SYSERR;
+  }
+  *duration = GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MILLISECONDS,
+                                             tms);
+  return GNUNET_OK;
+}
+
+
 enum GNUNET_GenericReturnValue
 TALER_MHD_parse_request_arg_timeout (
   struct MHD_Connection *connection,
@@ -224,22 +265,15 @@ TALER_MHD_parse_request_arg_timestamp (
   struct GNUNET_TIME_Timestamp *ts)
 {
   const char *s;
-  char dummy;
-  unsigned long long t;
 
   s = MHD_lookup_connection_value (connection,
                                    MHD_GET_ARGUMENT_KIND,
                                    fname);
   if (NULL == s)
-  {
-    *ts = GNUNET_TIME_UNIT_ZERO_TS;
     return GNUNET_OK;
-  }
-  if (1 !=
-      sscanf (s,
-              "%llu%c",
-              &t,
-              &dummy))
+  if (GNUNET_OK !=
+      GNUNET_STRINGS_fancy_time_to_timestamp (s,
+                                              ts))
   {
     MHD_RESULT mret;
 
@@ -253,7 +287,6 @@ TALER_MHD_parse_request_arg_timestamp (
       ? GNUNET_NO
       : GNUNET_SYSERR;
   }
-  *ts = GNUNET_TIME_timestamp_from_s (t);
   return GNUNET_OK;
 }
 
