@@ -39,17 +39,19 @@ postgres_prepare (struct GNUNET_PQ_Context *db)
                             " tamount"
                             ",json"
                             ",aamount"
+                            ",aamountc"
                             ",tamountc"
                             ",hash"
                             ",hashes"
                             ",cs_r_pubs"
                             ") VALUES "
-                            "($1, $2, $3, $4, $5, $6, $7);"),
+                            "($1, $2, $3, $4, $5, $6, $7, $8);"),
     GNUNET_PQ_make_prepare ("test_select",
                             "SELECT"
                             " tamount"
                             ",json"
                             ",aamount"
+                            ",aamountc"
                             ",tamountc"
                             ",hash"
                             ",hashes"
@@ -73,6 +75,7 @@ run_queries (struct GNUNET_PQ_Context *conn)
 {
   struct TALER_Amount tamount;
   struct TALER_Amount aamount[3];
+  struct TALER_Amount aamountc[2];
   struct TALER_Amount tamountc;
   struct GNUNET_HashCode hc =
   {{0xdeadbeef,0xdeadbeef,0xdeadbeef,0xdeadbeef,
@@ -103,6 +106,12 @@ run_queries (struct GNUNET_PQ_Context *conn)
   GNUNET_assert (GNUNET_OK ==
                  TALER_string_to_amount ("EUR:7.7",
                                          &tamount));
+  GNUNET_assert (GNUNET_OK ==
+                 TALER_string_to_amount ("USD:3.2",
+                                         &aamountc[0]));
+  GNUNET_assert (GNUNET_OK ==
+                 TALER_string_to_amount ("CHF:4.5",
+                                         &aamountc[1]));
   GNUNET_assert (GNUNET_OK ==
                  TALER_string_to_amount ("FOO:8.7",
                                          &tamountc));
@@ -123,6 +132,9 @@ run_queries (struct GNUNET_PQ_Context *conn)
       TALER_PQ_query_param_array_amount (3,
                                          aamount,
                                          conn),
+      TALER_PQ_query_param_array_amount_with_currency (2,
+                                                       aamountc,
+                                                       conn),
       TALER_PQ_query_param_amount_with_currency (conn,
                                                  &tamountc),
       GNUNET_PQ_query_param_fixed_size (&hc,
@@ -164,10 +176,12 @@ run_queries (struct GNUNET_PQ_Context *conn)
     struct TALER_Amount tamount2;
     struct TALER_Amount tamountc2;
     struct TALER_Amount *pamount;
+    struct TALER_Amount *pamountc;
     struct GNUNET_HashCode hc2;
     struct GNUNET_HashCode *hcs2;
     struct GNUNET_CRYPTO_CSPublicRPairP *out_cs_r_pubs;
     size_t npamount;
+    size_t npamountc;
     size_t nhcs;
     size_t n_rpubs;
     json_t *json2;
@@ -185,6 +199,10 @@ run_queries (struct GNUNET_PQ_Context *conn)
                                          "EUR",
                                          &npamount,
                                          &pamount),
+      TALER_PQ_result_spec_array_amount_with_currency (conn,
+                                                       "aamountc",
+                                                       &npamountc,
+                                                       &pamountc),
       TALER_PQ_result_spec_amount_with_currency ("tamountc",
                                                  &tamountc2),
       GNUNET_PQ_result_spec_auto_from_type ("hash",
@@ -222,6 +240,13 @@ run_queries (struct GNUNET_PQ_Context *conn)
                     TALER_amount_cmp (&aamount[i],
                                       &pamount[i]));
     }
+    GNUNET_break (2 == npamountc);
+    for (size_t i = 0; i < npamountc; i++)
+    {
+      GNUNET_break (0 ==
+                    TALER_amount_cmp (&aamountc[i],
+                                      &pamountc[i]));
+    }
     GNUNET_break (0 ==
                   TALER_amount_cmp (&tamountc,
                                     &tamountc2));
@@ -283,6 +308,7 @@ main (int argc,
                             " tamount taler_amount NOT NULL"
                             ",json VARCHAR NOT NULL"
                             ",aamount taler_amount[]"
+                            ",aamountc taler_amount_currency[]"
                             ",tamountc taler_amount_currency"
                             ",hash gnunet_hashcode"
                             ",hashes gnunet_hashcode[]"
