@@ -23,15 +23,15 @@
  * @author Marcello Stanisci
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_signatures.h"
-#include "taler_bank_service.h"
-#include "taler_exchange_service.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_exchange_service.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_curl_lib.h>
 #include <microhttpd.h>
-#include "taler_testing_lib.h"
+#include "taler/taler_testing_lib.h"
 
 #define CONFIG_FILE_FAKEBANK "test_bank_api_fakebank.conf"
 
@@ -165,7 +165,7 @@ main (int argc,
   else if (TALER_TESTING_has_in_name (argv[0],
                                       "_with_nexus"))
   {
-    bs = TALER_TESTING_BS_IBAN;
+    bs = TALER_TESTING_BS_FAKEBANK;
     cfgfile = CONFIG_FILE_NEXUS;
     if (GNUNET_SYSERR ==
         GNUNET_OS_check_helper_binary ("libeufin-bank",
