@@ -21,19 +21,19 @@
  * @brief testcase to test exchange's P2P payments
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_attributes.h"
-#include "taler_util.h"
-#include "taler_signatures.h"
-#include "taler_exchange_service.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_attributes.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_testing_lib.h>
 #include <microhttpd.h>
-#include "taler_bank_service.h"
-#include "taler_fakebank_lib.h"
-#include "taler_testing_lib.h"
-#include "taler_extensions.h"
+#include "taler/taler_bank_service.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/taler_extensions.h"
 
 /**
  * Configuration file we use.  One (big) configuration is used
