@@ -20,14 +20,14 @@
  * @author Christian Grothoff <christian@grothoff.org>
  * @author Marcello Stanisci
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 #include <gnunet/gnunet_json_lib.h>
-#include "taler_json_lib.h"
-#include "taler_exchangedb_lib.h"
+#include "taler/taler_json_lib.h"
+#include "taler/taler_exchangedb_lib.h"
 #include <microhttpd.h>
-#include "taler_fakebank_lib.h"
-#include "taler_testing_lib.h"
+#include "taler/taler_fakebank_lib.h"
+#include "taler/taler_testing_lib.h"
 
 
 /**
