@@ -21,19 +21,19 @@
  * @brief command for testing /deposit_confirmation.
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_auditor_service.h"
-#include "taler_testing_lib.h"
-#include "taler_signatures.h"
-#include "backoff.h"
+#include "taler/taler_auditor_service.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/backoff.h"
 
 /**
  * How long do we wait AT MOST when retrying?
  */
 #define MAX_BACKOFF GNUNET_TIME_relative_multiply ( \
-    GNUNET_TIME_UNIT_MILLISECONDS, 100)
+          GNUNET_TIME_UNIT_MILLISECONDS, 100)
 
 /**
  * How often do we retry before giving up?
