@@ -23,14 +23,14 @@
  * @author Marcello Stanisci
  * @author Özgür Kesim
  */
-#include "platform.h"
-#include "taler_exchange_service.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_exchange_service.h"
+#include "taler/taler_json_lib.h"
 #include <microhttpd.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_signatures.h"
-#include "taler_extensions.h"
-#include "taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_extensions.h"
+#include "taler/taler_testing_lib.h"
 
 /**
  * Information we track per withdrawn coin.
