@@ -21,12 +21,12 @@
  * @brief command for testing GET /aml/$OFFICER_PUB/decisions
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_testing_lib.h"
-#include "taler_signatures.h"
-#include "backoff.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/backoff.h"
 
 
 /**
