@@ -21,8 +21,8 @@
  * @brief common functions for commands
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_testing_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_testing_lib.h"
 
 
 enum GNUNET_GenericReturnValue
