@@ -21,12 +21,12 @@
  * @brief command for testing /deposit.
  * @author Marcello Stanisci
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_testing_lib.h"
-#include "taler_signatures.h"
-#include "backoff.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/backoff.h"
 
 
 /**
@@ -306,7 +306,7 @@ deposit_run (void *cls,
   const struct TALER_TESTING_Command *acc_var;
   const struct TALER_CoinSpendPrivateKeyP *coin_priv;
   struct TALER_CoinSpendPublicKeyP coin_pub;
-  const struct TALER_AgeCommitmentHash *phac;
+  const struct TALER_AgeCommitmentHashP *phac;
   const struct TALER_DenominationSignature *denom_pub_sig;
   struct TALER_PrivateContractHashP h_contract_terms;
   enum TALER_ErrorCode ec;
@@ -640,7 +640,7 @@ deposit_traits (void *cls,
   const struct TALER_CoinSpendPrivateKeyP *coin_spent_priv;
   struct TALER_CoinSpendPublicKeyP coin_spent_pub;
   const struct TALER_AgeCommitmentProof *age_commitment_proof=NULL;
-  const struct TALER_AgeCommitmentHash *h_age_commitment=NULL;
+  const struct TALER_AgeCommitmentHashP *h_age_commitment=NULL;
 
   if (! ds->command_initialized)
   {
