@@ -22,11 +22,11 @@
  * @author Christian Grothoff
  * @author Marcello Stanisci
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_signatures.h"
-#include "taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_testing_lib.h"
 
 
 /**
