@@ -21,10 +21,10 @@
  * @brief Command to get an exchange handle
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_testing_lib.h"
+#include "taler/taler_testing_lib.h"
 
 
 /**
