@@ -21,11 +21,11 @@
  * @brief Implement the revoke test command.
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_signatures.h"
-#include "taler_testing_lib.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_testing_lib.h"
 
 
 /**
