@@ -22,10 +22,10 @@
  * @brief Implement the testing CMDs for the /transfer GET operation.
  * @author Marcello Stanisci
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_testing_lib.h"
+#include "taler/taler_testing_lib.h"
 
 /**
  * State for a "track transfer" CMD.
