@@ -23,14 +23,14 @@
  * @author Marcello Stanisci
  * @author Özgür Kesim
  */
-#include "platform.h"
-#include "taler_json_lib.h"
+#include "taler/platform.h"
+#include "taler/taler_json_lib.h"
 #include <microhttpd.h>
 #include <gnunet/gnunet_curl_lib.h>
-#include "taler_signatures.h"
-#include "taler_extensions.h"
-#include "taler_testing_lib.h"
-#include "backoff.h"
+#include "taler/taler_signatures.h"
+#include "taler/taler_extensions.h"
+#include "taler/taler_testing_lib.h"
+#include "taler/backoff.h"
 
 
 /**
@@ -159,7 +159,7 @@ struct WithdrawState
    * its hash, respectively.
    */
   struct TALER_AgeCommitmentProof age_commitment_proof;
-  struct TALER_AgeCommitmentHash h_age_commitment;
+  struct TALER_AgeCommitmentHashP h_age_commitment;
 
   /**
    * Reserve history entry that corresponds to this operation.
