@@ -23,10 +23,10 @@
  * @author Christian Grothoff
  * @author Marcello Stanisci
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <taler/taler_twister_service.h>
-#include "taler_twister_testing_lib.h"
+#include "taler/taler_twister_testing_lib.h"
 
 
 /**
