@@ -34,7 +34,7 @@ struct TALER_ExchangeKeyValidityPS
   /**
    * Purpose is #TALER_SIGNATURE_AUDITOR_EXCHANGE_KEYS.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash of the auditor's URL (including 0-terminator).
