@@ -18,10 +18,10 @@
  * @brief functions for encrypting and decrypting contracts for P2P payments
  * @author Christian Grothoff <christian@grothoff.org>
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 #include <zlib.h>
-#include "taler_exchange_service.h"
+#include "taler/taler_exchange_service.h"
 
 
 /**
