@@ -35,7 +35,7 @@ struct TALER_DepositConfirmationPS
    * Purpose must be #TALER_SIGNATURE_EXCHANGE_CONFIRM_DEPOSIT.  Signed
    * by a `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash over the contract for which this deposit is made.
@@ -204,7 +204,7 @@ struct TALER_RefundConfirmationPS
   /**
    * Purpose must be #TALER_SIGNATURE_EXCHANGE_CONFIRM_REFUND.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash over the proposal data to identify the contract
@@ -315,7 +315,7 @@ struct TALER_RefreshMeltConfirmationPS
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_MELT.   Signed
    * by a `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Commitment made in the /refresh/melt.
@@ -392,7 +392,7 @@ struct TALER_WithdrawConfirmationPS
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW.   Signed by a
    * `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Commitment made in the /withdraw call.
@@ -525,7 +525,7 @@ struct TALER_ExchangeKeySetPS
    * Purpose is #TALER_SIGNATURE_EXCHANGE_KEY_SET.   Signed
    * by a `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time of the key set issue.
@@ -661,7 +661,7 @@ struct TALER_WireDepositDataPS
    * Purpose header for the signature over the contract with
    * purpose #TALER_SIGNATURE_EXCHANGE_CONFIRM_WIRE_DEPOSIT.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Total amount that was transferred.
@@ -766,7 +766,7 @@ struct TALER_ConfirmWirePS
    * Purpose header for the signature over the contract with
    * purpose #TALER_SIGNATURE_EXCHANGE_CONFIRM_WIRE.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash over the wiring information of the merchant.
@@ -883,7 +883,7 @@ struct TALER_RecoupConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_RECOUP
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange receive the recoup request?
@@ -978,7 +978,7 @@ struct TALER_RecoupRefreshConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_RECOUP_REFRESH
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange receive the recoup request?
@@ -1075,7 +1075,7 @@ struct TALER_DenominationUnknownAffirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_AFFIRM_DENOM_UNKNOWN
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange sign this message.
@@ -1147,7 +1147,7 @@ struct TALER_DenominationExpiredAffirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_AFFIRM_DENOM_EXPIRED
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange sign this message.
@@ -1238,7 +1238,7 @@ struct TALER_ReserveCloseConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_RESERVE_CLOSED
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange initiate the wire transfer.
@@ -1351,7 +1351,7 @@ struct TALER_PurseCreateDepositConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_PURSE_CREATION
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange receive the deposits.
@@ -1463,7 +1463,7 @@ struct TALER_CoinPurseRefundConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_PURSE_REFUND
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Public key of the purse.
@@ -1557,7 +1557,7 @@ struct TALER_PurseMergedConfirmationPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_PURSE_MERGED
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * When did the exchange receive the deposits.
@@ -1680,7 +1680,7 @@ struct TALER_PurseStatusPS
    * Purpose must be #TALER_SIGNATURE_EXCHANGE_PURSE_STATUS.  Signed
    * by a `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time when the purse was merged, possibly 'never'.
@@ -1769,7 +1769,7 @@ struct TALER_ExchangeAttestPS
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_RESERVE_ATTEST_DETAILS
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Time when the attestation was made.
