@@ -18,8 +18,8 @@
  * @brief Common utility functions for dealing with payto://-URIs
  * @author Florian Dold
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 
 /**
