@@ -18,9 +18,9 @@
  * @brief Common functions for the exchange security modules
  * @author Florian Dold <dold@taler.net>
  */
-#include "platform.h"
-#include "taler_util.h"
-#include "taler_signatures.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
+#include "taler/taler_signatures.h"
 #include "secmod_common.h"
 #include <poll.h>
 #ifdef __linux__
@@ -219,11 +219,15 @@ TES_wake_clients (void)
        client = client->next)
   {
 #ifdef __linux__
+    if (-1 == client->esock)
+      continue;
     GNUNET_assert (sizeof (num) ==
                    write (client->esock,
                           &num,
                           sizeof (num)));
 #else
+    if (-1 == client->esock_in)
+      continue;
     GNUNET_assert (sizeof (num) ==
                    write (client->esock_in,
                           &num,
@@ -365,26 +369,6 @@ TES_await_ready (struct TES_Client *client)
 }
 
 
-void
-TES_free_client (struct TES_Client *client)
-{
-  GNUNET_assert (0 == pthread_mutex_lock (&TES_clients_lock));
-  GNUNET_CONTAINER_DLL_remove (TES_clients_head,
-                               TES_clients_tail,
-                               client);
-  GNUNET_assert (0 == pthread_mutex_unlock (&TES_clients_lock));
-  GNUNET_break (0 == close (client->csock));
-#ifdef __linux__
-  GNUNET_break (0 == close (client->esock));
-#else
-  GNUNET_break (0 == close (client->esock_in));
-  GNUNET_break (0 == close (client->esock_out));
-#endif
-  pthread_detach (client->worker);
-  GNUNET_free (client);
-}
-
-
 /**
  * Main function of a worker thread that signs.
  *
@@ -400,7 +384,6 @@ sign_worker (void *cls)
       client->cb.init (client))
   {
     GNUNET_break (0);
-    TES_free_client (client);
     return NULL;
   }
   while (! in_shutdown)
@@ -411,12 +394,25 @@ sign_worker (void *cls)
           client->cb.updater (client))
         break;
     }
-    if (GNUNET_SYSERR ==
-        TES_read_work (client,
-                       client->cb.dispatch))
-      break;
+    else
+    {
+      if (GNUNET_SYSERR ==
+          TES_read_work (client,
+                         client->cb.dispatch))
+        break;
+    }
   }
-  TES_free_client (client);
+  GNUNET_break (0 == close (client->csock));
+  client->csock = -1;
+#ifdef __linux__
+  GNUNET_break (0 == close (client->esock));
+  client->esock = -1;
+#else
+  GNUNET_break (0 == close (client->esock_in));
+  client->esock_in = -1;
+  GNUNET_break (0 == close (client->esock_out));
+  client->esock_out = -1;
+#endif
   return NULL;
 }
 
@@ -448,8 +444,15 @@ listen_job (void *cls)
               &sa_len);
   if (-1 == s)
   {
+    bool st = ( (ENFILE == errno) ||
+                (EMFILE == errno) );
     GNUNET_log_strerror (GNUNET_ERROR_TYPE_WARNING,
                          "accept");
+    if (st)
+    {
+      GNUNET_SCHEDULER_cancel (listen_task);
+      listen_task = NULL;
+    }
     return;
   }
 #ifdef __linux__
@@ -473,6 +476,7 @@ listen_job (void *cls)
 #endif
   {
     struct TES_Client *client;
+    struct TES_Client *nxt;
 
     client = GNUNET_new (struct TES_Client);
     client->cb = *cb;
@@ -484,6 +488,24 @@ listen_job (void *cls)
     client->esock_out = e[0];
 #endif
     GNUNET_assert (0 == pthread_mutex_lock (&TES_clients_lock));
+    for (struct TES_Client *pos = TES_clients_head;
+         NULL != pos;
+         pos = nxt)
+    {
+      nxt = pos->next;
+      if (-1 == pos->csock)
+      {
+        void *rval;
+
+        GNUNET_CONTAINER_DLL_remove (TES_clients_head,
+                                     TES_clients_tail,
+                                     pos);
+        GNUNET_break (0 ==
+                      pthread_join (pos->worker,
+                                    &rval));
+        GNUNET_free (pos);
+      }
+    }
     GNUNET_CONTAINER_DLL_insert (TES_clients_head,
                                  TES_clients_tail,
                                  client);
@@ -496,7 +518,19 @@ listen_job (void *cls)
     {
       GNUNET_log_strerror (GNUNET_ERROR_TYPE_WARNING,
                            "pthread_create");
-      TES_free_client (client);
+      GNUNET_assert (0 == pthread_mutex_lock (&TES_clients_lock));
+      GNUNET_CONTAINER_DLL_remove (TES_clients_head,
+                                   TES_clients_tail,
+                                   client);
+      GNUNET_assert (0 == pthread_mutex_unlock (&TES_clients_lock));
+      GNUNET_break (0 == close (client->csock));
+#ifdef __linux__
+      GNUNET_break (0 == close (client->esock));
+#else
+      GNUNET_break (0 == close (client->esock_in));
+      GNUNET_break (0 == close (client->esock_out));
+#endif
+      GNUNET_free (client);
     }
   }
 }
@@ -538,7 +572,6 @@ TES_listen_start (const struct GNUNET_CONFIGURATION_Handle *cfg,
                                         &TES_smpub.eddsa_pub);
   }
 
-
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_filename (cfg,
                                                section,
@@ -570,6 +603,8 @@ TES_listen_start (const struct GNUNET_CONFIGURATION_Handle *cfg,
 void
 TES_listen_stop (void)
 {
+  struct TES_Client *client;
+
   if (NULL != listen_task)
   {
     GNUNET_SCHEDULER_cancel (listen_task);
@@ -590,4 +625,18 @@ TES_listen_stop (void)
   GNUNET_free (unixpath);
   in_shutdown = true;
   TES_wake_clients ();
+  GNUNET_assert (0 == pthread_mutex_lock (&TES_clients_lock));
+  while (NULL != (client = TES_clients_head))
+  {
+    void *rval;
+
+    GNUNET_CONTAINER_DLL_remove (TES_clients_head,
+                                 TES_clients_tail,
+                                 client);
+    GNUNET_break (0 ==
+                  pthread_join (client->worker,
+                                &rval));
+    GNUNET_free (client);
+  }
+  GNUNET_assert (0 == pthread_mutex_unlock (&TES_clients_lock));
 }
