@@ -34,7 +34,7 @@ struct TALER_SigningKeyAnnouncementPS
    * Purpose must be #TALER_SIGNATURE_SM_SIGNING_KEY.
    * Used with an EdDSA signature of a `struct TALER_SecurityModulePublicKeyP`.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Public signing key of the exchange this is about.
@@ -111,7 +111,7 @@ struct TALER_DenominationKeyAnnouncementPS
    * Purpose must be #TALER_SIGNATURE_SM_RSA_DENOMINATION_KEY.
    * Used with an EdDSA signature of a `struct TALER_SecurityModulePublicKeyP`.
    */
-  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+  struct GNUNET_CRYPTO_SignaturePurpose purpose;
 
   /**
    * Hash of the denomination public key.
