@@ -18,8 +18,8 @@
  * @brief Tests for CS crypto helper
  * @author Christian Grothoff
  */
-#include "platform.h"
-#include "taler_util.h"
+#include "taler/platform.h"
+#include "taler/taler_util.h"
 
 /**
  * Configuration has 1 minute duration and 5 minutes lookahead, but
